@@ -1,10 +1,10 @@
 /*
-  Copyright (C) 2000-2006
+  Copyright (C) 2000-2007
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
   This file is part of xmds.
- 
+
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
@@ -21,14 +21,14 @@
 */
 
 /*
-  $Id: dom3.h 1271 2007-01-07 23:51:00Z paultcochrane $
+  $Id: dom3.h 1586 2007-11-11 21:55:49Z paultcochrane $
 */
 
 /*! @file dom3.h
-  @brief Provides the abstracted Document Object Model (DOM) level 3 
+  @brief Provides the abstracted Document Object Model (DOM) level 3
   interface as specified in the W3C Working Draft as of 05 June 2001.
-  
-  Most of the documentation of this file is taken directly from the 
+
+  Most of the documentation of this file is taken directly from the
   W3C Working Draft of 05 June 2001.
 */
 
@@ -60,7 +60,7 @@ typedef long DOMKey;         //!< Defines the DOM key
 struct DOMException {
 
   //! Enumerator containing the DOM defined exception numbers
-  /*! 
+  /*!
     The exception code is an integer indicating the type of error generated
   */
   enum {
@@ -68,7 +68,7 @@ struct DOMException {
     DOMSTRING_SIZE_ERR              =  2,  //!< If the specified range of text does not fit into a DOMString
     HIERARCHY_REQUEST_ERR           =  3,  //!< If any node is inserted somewhere it doesn't belong
     //! If a node is used in a different document than the one that created it (that doesn't support it)
-    WRONG_DOCUMENT_ERR              =  4,  
+    WRONG_DOCUMENT_ERR              =  4,
     INVALID_CHARACTER_ERR           =  5,  //!< If an invalid or illegal character is specified, such as in a name
     NO_DATA_ALLOWED_ERR             =  6,  //!< If data is specified for a node which does not support data
     NO_MODIFICATION_ALLOWED_ERR     =  7,  //!< If an attempt is made to modify an object where modifications are not allowed
@@ -81,7 +81,7 @@ struct DOMException {
     SYNTAX_ERR                      = 12,  //!< If an invalid or illegal string is specified
     INVALID_MODIFICATION_ERR        = 13,  //!< If an attempt is made to modify the type of the underlying object
     //! If an attempt is made to create or change an object in a way which is incorrect with regard to namespaces
-    NAMESPACE_ERR                   = 14,  
+    NAMESPACE_ERR                   = 14,
     INVALID_ACCESS_ERR              = 15   //!< If a parameter or an operation is not supported by the underlying object
   };
 
@@ -137,11 +137,14 @@ class DOMImplementation {
 
 public :
 
+  //! Destructor
+  virtual ~DOMImplementation() {};
+
   //! Tests if the DOM implementation implements a specific feautre
   /*!
-    @param feature The name of the feature to test (case-insensitive).  
+    @param feature The name of the feature to test (case-insensitive).
     The name must be an XML name
-    @param version This is the version number of the feature to test.  In DOM 
+    @param version This is the version number of the feature to test.  In DOM
     Level 2, the string can be either "2.0" or "1.0"
   */
   virtual bool hasFeature(
@@ -168,10 +171,10 @@ public :
   //! Creates a DOM document object of the specified type with its document element
   /*!
     @param namespaceURI The namespace URI of the document to create
-    @param qualifiedName The qualified name of the document element to be 
+    @param qualifiedName The qualified name of the document element to be
     created
-    @param doctype The type of document to be created or @c null.  When 
-    doctype is not @c null, its @c Node.ownerDocument attribute is set to the 
+    @param doctype The type of document to be created or @c null.  When
+    doctype is not @c null, its @c Node.ownerDocument attribute is set to the
     document being created
   */
   virtual Document* createDocument(
@@ -208,13 +211,16 @@ class Node;
 class NodeList {
 
 public :
+  //! Destructor
+  virtual ~NodeList() {};
+
   //! Gets an item from the node list at index
   /*!
     Returns the @c index th item in the collection.  If @c index is greater
     than or eaual to the number of nodes in the list, this returns @c null.
     @param index Index into the collection
   */
-  virtual Node* item( unsigned long      index) const = 0;
+  virtual Node* item(unsigned long index) const = 0;
 
   //! Returns the length of the node list
   /*
@@ -244,6 +250,9 @@ class NamedNodeMap {
 
 public :
 
+  //! Destructor
+  virtual ~NamedNodeMap() {};
+
   //! Gets a named item
   /*!
     Retrieves a node specified by name
@@ -260,12 +269,12 @@ public :
     As the @c nodeName attribute is used to derive the name which the node
     must be stored under, multiple nodes of certain types (those that have a
     "special" string value) cannot be stored as the names would clash.  This
-    is seen as preferable to allowing nodes to be aliased.  
-    
+    is seen as preferable to allowing nodes to be aliased.
+
     @param arg A node to store in this map.  The node will later be
     accessible using the value of its @c nodeName attribute.
   */
-  virtual Node* setNamedItem( Node& arg) = 0;
+  virtual Node* setNamedItem(Node& arg) = 0;
 
   //! Removes a named item
   /*!
@@ -324,7 +333,7 @@ public :
     accessible using the value of its @c namespaceURI and @c localname
     attributes.
   */
-  virtual Node* setNamedItemNS( Node& arg) = 0;
+  virtual Node* setNamedItemNS(Node& arg) = 0;
 
   //! Removes the named item namespace
   /*!
@@ -345,7 +354,7 @@ public :
   */
   virtual Node* removeNamedItemNS(
                                   const DOMString& namespaceURI,
-                                  const DOMString& localname) = 0;      
+                                  const DOMString& localname) = 0;
 };
 
 // **************************************************************************
@@ -377,13 +386,13 @@ public :
 
   //! Destructor
   virtual ~Node() {};
-        
+
   //! Enumerator containing the document node numbers
   /*!
     These are the @c nodeTypes; an integer indicating which type of node
     this is.
 
-    The values of @c nodeName, @c nodeValue, and @c attributes vary 
+    The values of @c nodeName, @c nodeValue, and @c attributes vary
     according to the node type as follows:
     <table>
     <tr>
@@ -550,13 +559,13 @@ public :
     Inserts the node @c newChild before the existing child node @c refChild.
     If @c refChild is @c null, insert @c newChild at the end of the list of
     children.
-    
+
     If @c newChild is a @c DocumentFragement object, all of its children are
     inserted, in the same order, before @c refChild.  If the @c newChild is
     already in the tree, it is first removed.
 
     @param newChild The node to insert
-    @param refChild The reference node, i.e., the node before which the 
+    @param refChild The reference node, i.e., the node before which the
     new node must be inserted
   */
   virtual Node* insertBefore(
@@ -587,8 +596,7 @@ public :
 
     @param oldChild The node being removed
   */
-  virtual Node* removeChild(
-                            Node* oldChild) = 0;
+  virtual Node* removeChild(Node* oldChild) = 0;
 
   //! Appends a child node
   /*!
@@ -599,7 +607,7 @@ public :
     the entire contents of the document fragment are moved into the child
     list of this node
   */
-  virtual Node* appendChild( Node* newChild) = 0;
+  virtual Node* appendChild(Node* newChild) = 0;
 
   //! Determines if object has child nodes
   /*!
@@ -626,7 +634,7 @@ public :
     specified node; if @c false, clone only the node itself (and its
     attributes, if it is an @c Element).
   */
-  virtual Node* cloneNode( const bool& deep) const = 0;
+  virtual Node* cloneNode(const bool& deep) const = 0;
 
   //! Puts all Text nodes into a ``normal'' form
   /*!
@@ -654,7 +662,7 @@ public :
     the string "2.0".  If the version is not specified, supoorting any
     version of the feature will cause the method to return @c true
   */
-  virtual bool isSupported( DOMString& feature, DOMString& version) const =
+  virtual bool isSupported(DOMString& feature, DOMString& version) const =
       0;
 
   //! Returns the namespace URI as a DOMString
@@ -687,7 +695,7 @@ public :
 
     For nodes of any type other than @c ELEMENT_NODE and @c ATTRIBUTE_NODE
     and nodes created with a DOM Level 1 method, such as @c createElement
-    from the @c Document interface, this is always @c null.    
+    from the @c Document interface, this is always @c null.
   */
   virtual const DOMString* prefix() const = 0;
 
@@ -701,7 +709,7 @@ public :
 
   //! Returns the local name as a DOMString
   /*!
-    Returns the local part of the qualified name of this node.  
+    Returns the local part of the qualified name of this node.
 
     For nodes of any type other than @c ELEMENT_NODE and @c ATTRIBUTE_NODE
     and nodes created with a DOM Level 1 method, such as @c createElement
@@ -782,7 +790,7 @@ public :
     </tr>
     <tr>
     <td>ELEMENT_NODE, ENTITY_NODE, ENTITY_REFERENCE_NODE, DOCUMENT_NODE, DOCUMENT_FRAGMENT_NODE</td>
-    <td>concatenation of the @c textContent attribute value of every child node, excluding COMMENT_NODE and 
+    <td>concatenation of the @c textContent attribute value of every child node, excluding COMMENT_NODE and
     PROCESSING_INSTRUCTION_NODE nodes</td>
     </tr>
     <tr>
@@ -859,17 +867,17 @@ public :
     two nodes are exactly the same object) which can be tested with @c
     Node.isSameNode.  All objects that are the same will also be equal,
     though the reverse may not be true.
-    
+
     @param arg The node to compare equality with
-    @param deep If @c true, recursively compare the subtrees; if @c false, 
-    compare only the nodes themselves, (and its attributes, if it is 
+    @param deep If @c true, recursively compare the subtrees; if @c false,
+    compare only the nodes themselves, (and its attributes, if it is
     an @c Element)
   */
   virtual bool equalsNode(
                           const Node* arg,
                           bool deep) const = 0;
 
-  //! Makes available a Node's specialised interface. 
+  //! Makes available a Node's specialised interface.
   /*!
     This method makes available a @c Node's specialised interface.
     @param feature The name of the feature requested (case-insensitive)
@@ -887,9 +895,9 @@ public :
   /*!
     Sets the node read only attribute.  Not specified in the DOM Level 3.
 
-    @param newReadOnly Boolean specifying @c true for read only, @c false 
+    @param newReadOnly Boolean specifying @c true for read only, @c false
     otherwise
-    @param deep If @c true, then sets the attribute recursively for the 
+    @param deep If @c true, then sets the attribute recursively for the
     subtrees, if @c false, then only sets the attribute for the current node
   */
   virtual void setReadOnly(
@@ -921,7 +929,7 @@ class EntityReference;
 class Document : public virtual Node {
 
 public :
-        
+
   //! Returns the @c DOMKey
   /*!
     A method which returns the @c DOMKey.  This is a utility method defined
@@ -960,7 +968,7 @@ public :
     element with a qualified name and namespace URI, use the @c
     createElementNS method.
 
-    @param tagName The name of the element to instantiate.  For XML this 
+    @param tagName The name of the element to instantiate.  For XML this
     is case-sensitive.
   */
   virtual Element* createElement(
@@ -1037,7 +1045,7 @@ public :
     the order in which they are encountered in a preorder traversal of the
     @c Document tree.
 
-    @param tagName The name of the tag to match on.  The special value 
+    @param tagName The name of the tag to match on.  The special value
     "*" matches all tags.
   */
   virtual NodeList* getElementsByTagName(
@@ -1051,14 +1059,14 @@ public :
     node has no parent; (@c parentNode is @c null).  The source node is not
     altered or removed from the original document; this method creates a new
     copy of the source code.
-    
+
     For all nodes, importing a node creates a node object owned by the
     importing document, with attribute values identical to the source node's
     @c nodeName and @c nodeType, plus the attributes related to namespaces
     (@c prefix, @c localName, and @c namespaceURI).  As in the @c cloneNode
     operation on a @c Node, the source node is not altered.  @see Node
   */
-  virtual Node* importNode( const Node* importNode, const bool& deep) = 0;
+  virtual Node* importNode(const Node* importNode, const bool& deep) = 0;
 
   //! Creates an element's namespace
   /*!
@@ -1089,7 +1097,7 @@ public :
     @param namespaceURI The namespace URI of the elements to match on.  The
     special value "*" matches all namespaces
 
-    @param localname of the elements to match on.  The special value "*" 
+    @param localname of the elements to match on.  The special value "*"
     matches all local names
   */
   virtual NodeList* getElementsByTagNameNS(
@@ -1121,7 +1129,7 @@ public :
     Sets the actual encoding to the specified value.  This is not part of
     the W3C DOM Level 3.
 
-    @param newActualEncoding The new actual encoding to set the actual 
+    @param newActualEncoding The new actual encoding to set the actual
     encoding to.
   */
   virtual void setActualEncoding(
@@ -1153,13 +1161,13 @@ public :
 
   //! Sets the document to be standalone
   /*!
-    Sets the boolean specifying that the document is standalone.  This is not 
+    Sets the boolean specifying that the document is standalone.  This is not
     defined in the W3C DOM level 3.
 
     @param newStandalone A boolean specifying if the document is standalone
     or not
   */
-  virtual void setStandalone( const bool& newStandalone) = 0;
+  virtual void setStandalone(const bool& newStandalone) = 0;
 
   //! Determines if strict error checking is on
   /*!
@@ -1175,7 +1183,7 @@ public :
   /*!
     Turns strict error checking on by setting the appropriate flag.
 
-    @param newStrictErrorChecking Boolean value defining whether or not 
+    @param newStrictErrorChecking Boolean value defining whether or not
     strict error checking is on
   */
   virtual void setStrictErrorChecking(
@@ -1433,7 +1441,7 @@ public :
     @param namespaceURI The name space URI of the elements to match on.  The
     special value "*" matches all namespaces.
 
-    @param localname The local name of the elements to match on.  The 
+    @param localname The local name of the elements to match on.  The
     special value "*" matches all local names.
   */
   virtual NodeList* getElementsByTagNameNS(
@@ -1466,7 +1474,7 @@ public :
   */
   virtual bool hasAttributeNS(
                               const DOMString& namespaceURI,
-                              const DOMString& localname) const = 0;    
+                              const DOMString& localname) const = 0;
 };
 
 // **************************************************************************
@@ -1480,7 +1488,7 @@ public :
   The @c Attr interface represents an attribute in an @c Element object.
   Typically the allowable values for the attribute are defined in a document
   type definition.
-  
+
   @c Attr objects inherit the @c Node interface, but since they are not
   actually child nodes of the element they describe, the DOM does not
   consider them part of the document tree.  Thus, the @c Node attributes @c
@@ -1536,7 +1544,7 @@ public :
   virtual const DOMString* value() const = 0;
 
   //! Sets the attribute value
-  /*! 
+  /*!
     Convenience function to set the attribute value.  Not explicitly defined
     in the W3C DOM Level 3, however, it is certainly implied that such a
     function should exist.
@@ -1553,7 +1561,7 @@ public :
     Returns the @c Element node this attribute is attached to or @c null if
     this attribute is not in use.
   */
-  virtual const Element* ownerElement() const = 0; 
+  virtual const Element* ownerElement() const = 0;
 
   //! Sets the owner element of the attribute
   /*!
@@ -1646,8 +1654,8 @@ public :
     @c length reflect the change.
 
     @param offset The offset from which to start removing
-    @param count The number of 16-bit units to delete.  If the sum of @c 
-    offset and @c count exceeds @c length then all 16-bit units from @c 
+    @param count The number of 16-bit units to delete.  If the sum of @c
+    offset and @c count exceeds @c length then all 16-bit units from @c
     offset to the end of the data are deleted
   */
   virtual void deleteData(
@@ -2031,7 +2039,7 @@ public :
 /*!
   @c EntityReference objects may be inserted into the structure model when
   an entity reference is in the source document, or when the user wishes to
-  insert an entity reference. 
+  insert an entity reference.
 */
 class EntityReference : public virtual Node { };
 
