@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: main.cc 1597 2007-11-17 13:41:38Z paultcochrane $
+  $Id: main.cc 1885 2008-03-18 15:24:56Z paultcochrane $
 */
 
 /*!
@@ -79,6 +79,22 @@
 
 using namespace std;
 
+//! Escape the given string for inclusion as a string in C source.
+//! e.g. escapeStringC(a\b"c) -> a\\b\"c
+//! (Read the above as actual strings, not C strings.)
+//! \todo Should we also escape e.g. non-printable characters?
+void escapeStringC(string& s)
+{
+  for (size_t i = 0; i < s.length(); i++) {
+    if (s[i] == '\\' || s[i] == '"') {
+      // escape the character
+      s.insert(i, "\\");
+      // move one forward
+      i++;
+    }
+  }
+}
+
 // *********************************************************************
 
 //! Displays xmds usage
@@ -399,7 +415,7 @@ void outputTemplate(const char* outfilename) {
        */
       cout << "This is xmds, version " << VERSION <<
         " (" << REVISION <<")\n" <<
-        "Copyright 2000-2007 Greg Collecutt, Joseph Hope "<<
+        "Copyright 2000-2008 Greg Collecutt, Joseph Hope "<<
         "and the xmds-devel team\n" <<
         "xmds is available from http://www.xmds.org\n\n" <<
         "Writing a template to file with filename: " << outfilename << "\n";
@@ -418,9 +434,13 @@ void outputTemplate(const char* outfilename) {
 bool debugFlag = 0;             //!< Print debugging info about xmds processes
 bool xmlDebugFlag = 0;          //!< Print debugging info about xml parsing processes
 vector<string> simulationText;  //!< The text of the xmds simulation script
-vector<string> simHeaderText;   //!< The text of the xmds script's header
-vector<string> simBodyText;     //!< The text of the xmds script's body
-vector<string> simFooterText;   //!< The text of the xmds script's footer
+
+//! The lines of the xmds script's header. Escaped for source output.
+vector<string> simHeaderText;
+//! The lines of the xmds script's body. Escaped for source output.
+vector<string> simBodyText;
+//! The lines of the xmds script's footer. Escaped for source output.
+vector<string> simFooterText;
 
 /*!
   @brief The main routine.
@@ -563,28 +583,6 @@ int main(
       }
     }
 
-    // now we need to replace all occurrences of " with \"
-    for (unsigned int i=0; i<simulationText.size(); i++) {
-        string simulationLine = simulationText[i];
-      unsigned int lineLen = simulationLine.size();
-      for (unsigned int j=0; j<lineLen; j++) {
-        if (simulationLine[j] == '\"') {
-          if (debugFlag) {
-            cout << "Replaced a double quote at location " << j <<
-              ", lineLen = " << lineLen << "\n";
-            cout << "Line is:\n" << simulationLine.c_str() << "\n";
-          }
-          size_t textPos = j;
-          simulationLine.replace(textPos, 1, "\\\"", 2);
-          j++;
-          lineLen++;  // because the line length increases as we add more characters
-        }
-      }
-      // I could check to make sure that simulationLine was altered, but
-      // I can't be bothered, and it should be pretty quick anyway
-      simulationText[i] = simulationLine;
-    }
-
     // now we need to tear the text to bits a little
     // first, grab the test up until we have a <simulation> tag
     // then, go from the back, dropping anything that isn't a > symbol,
@@ -619,12 +617,15 @@ int main(
       }
       if (!foundSimStartTag && !foundSimEndTag) {
         simHeaderText.push_back(simulationText[i]);
+        escapeStringC(simHeaderText.back());
       }
       if (foundSimStartTag && !foundSimEndTag) {
         simBodyText.push_back(simulationText[i]);
+        escapeStringC(simBodyText.back());
       }
       if (foundSimStartTag && foundSimEndTag) {
         simFooterText.push_back(simulationText[i]);
+        escapeStringC(simFooterText.back());
       }
     }
 
@@ -704,7 +705,7 @@ int main(
   cout << "This is xmds, version " <<
     myxmdsSimulation.parameters()->version.c_str() <<
     " (" << REVISION << ")" << "\n";
-  cout << "Copyright 2000-2007 Greg Collecutt, Joseph Hope " <<
+  cout << "Copyright 2000-2008 Greg Collecutt, Joseph Hope " <<
     "and the xmds-devel team\n" <<
     "xmds is available from http://www.xmds.org\n\n";
 
