@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: xmds_breakpoint.cc 1620 2007-11-26 04:11:59Z grahamdennis $
+  $Id: xmds_breakpoint.cc 1885 2008-03-18 15:24:56Z paultcochrane $
 */
 
 /*! @file xmds_breakpoint.cc
@@ -208,14 +208,14 @@ void xmdsBreakpoint::writeRoutines(FILE *const outfile) const
       "// *************************\n"
       "void _segment%li(unsigned long cycle) {\n"
       "\n", segmentNumber);
-  
+
   if (autoIncrementFilenames) {
     fprintf(outfile,
         "_breakpointAutoIncrementCounter++;\n"
         "char *_baseFilename = (char*)malloc(100);\n"
-        "snprintf(_baseFilename, 100, \"%%li\", _breakpointAutoIncrementCounter);\n"
-      );
-  } else {
+        "snprintf(_baseFilename, 100, \"%%li\", _breakpointAutoIncrementCounter);\n");
+  }
+  else {
     // get the xsil filename, rip off the extension if it equals '.xsil'
     // otherwise, leave it alone
     XMLString xsilFilename = breakpointFilename;
@@ -227,11 +227,11 @@ void xmdsBreakpoint::writeRoutines(FILE *const outfile) const
     if (testExtension == xsilExtension) {
       xsilFilename.deleteData(xsilFilename.length()-5, 5);
     }
-    
+
     fprintf(outfile,
         "char *_baseFilename = \"%s\";\n", xsilFilename.c_str());
   }
-    
+
   if (simulation()->parameters()->usempi &&
       !simulation()->parameters()->stochastic)
     fprintf(outfile, "MPI_Barrier(MPI_COMM_WORLD);\n");
@@ -270,22 +270,23 @@ void xmdsBreakpoint::writeRoutines(FILE *const outfile) const
   // put the header text into the output from the xmds script
   fprintf(outfile, "\n");
   for (unsigned int i = 0; i < simHeaderText.size(); i++) {
-    fprintf(outfile, "      fprintf(_outfile, \"%s\\n\");\n",
-        simHeaderText[i].c_str());
+    fprintf(outfile, "      fprintf(_outfile, \"%%s\\n\", \"%s\");\n",
+            simHeaderText[i].c_str());
   }
 
   // put the body text into the output from the xmds script
   fprintf(outfile, "\n");
   for (unsigned int i = 0; i < simBodyText.size(); i++) {
-    fprintf(outfile, "      fprintf(_outfile, \"%s\\n\");\n",
-        simBodyText[i].c_str());
+    fprintf(outfile, "      fprintf(_outfile, \"%%s\\n\", \"%s\");\n",
+            simBodyText[i].c_str());
   }
 
   // biff out some informative text about xmds - this is the footer
   fprintf(outfile,
       "    fprintf(_outfile, \"\\n<info>\\n\");\n"
-      "    fprintf(_outfile, \"Output generated with xmds version %s.\\n\");\n",
-          simulation()->parameters()->version.c_str());
+      "    fprintf(_outfile, \"Output generated with xmds version %s (%s).\\n\");\n",
+          simulation()->parameters()->version.c_str(),
+          simulation()->parameters()->revision.c_str());
   fprintf(outfile,
       "    fprintf(_outfile, "
       "\"See http://www.xmds.org for more information.\\n\");\n");
@@ -467,8 +468,8 @@ void xmdsBreakpoint::writeRoutines(FILE *const outfile) const
   // put the footer text into the xmds simulation output
   fprintf(outfile, "\n");
   for (unsigned int i = 0; i < simFooterText.size(); i++) {
-    fprintf(outfile, "      fprintf(_outfile, \"%s\\n\");\n",
-        simFooterText[i].c_str());
+    fprintf(outfile, "      fprintf(_outfile, \"%%s\\n\", \"%s\");\n",
+            simFooterText[i].c_str());
   }
 
   // close things down and tidy up a bit
@@ -498,15 +499,13 @@ void xmdsBreakpoint::writeRoutines(FILE *const outfile) const
       // k-space
       fprintf(outfile,
           "coordinate = -(_main_lattice%1$li)/2 * _main_dk%1$li;\n"
-          "for (long _i0 = -(_main_lattice%1$li)/2; _i0 < (_main_lattice%1$li+1)/2; _i0++) {\n"
-          "\tcoordinate += _main_dk%1$li;\n", i);
+          "for (long _i0 = -(_main_lattice%1$li)/2; _i0 < (_main_lattice%1$li+1)/2; _i0++, coordinate += _main_dk%1$li) {\n", i);
     }
     else {
       // x-space
       fprintf(outfile,
           "coordinate = _main_xmin%1$li;\n"
-          "for (long _i0 = 0; _i0 < _main_lattice%1$li; _i0++) {\n"
-          "\tcoordinate += _main_dx%1$li;\n", i);
+          "for (long _i0 = 0; _i0 < _main_lattice%1$li; _i0++, coordinate += _main_dx%1$li) {\n", i);
     }
     fprintf(outfile,
         "\tfwrite(&coordinate, sizeof(double), 1, fpBinary);\n"
