@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: xmds_field.cc 1637 2007-12-31 04:00:26Z joehope $
+  $Id: xmds_field.cc 1885 2008-03-18 15:24:56Z paultcochrane $
 */
 
 /*! @file xmds_field.cc
@@ -1219,30 +1219,30 @@ void xmdsField::writePlanCreationCalls(
           myName.c_str(), myName.c_str(), useMeasureStr, useWisdomStr);
     }
     else if (simulation()->parameters()->fftwVersion == 3) {
-		list<XMLString> vectorNamesList;
-		// get the names of all vectors in this field
-		vectorNames(vectorNamesList);
-		for (list<XMLString>::const_iterator
-			 pXMLString = vectorNamesList.begin();
-			 pXMLString != vectorNamesList.end();
-			 pXMLString++) {
-			const xmdsVector *nextVector;
-			getVector(*pXMLString, nextVector);
-			if (!nextVector->needsFFTWRoutines()) {
-				continue;
-			}
-			fprintf(outfile,
-					"_%1$s_%2$s_forward_plan = fftw_plan_many_dft(_%1$s_ndims, "
-					"_fftw_lattice, _%1$s_%2$s_ncomponents, \n"
-					"                                         "
-					"reinterpret_cast<fftw_complex*>(_%1$s_%2$s), NULL, "
-					"_%1$s_%2$s_ncomponents, 1, \n"
-					"                                         "
-					"reinterpret_cast<fftw_complex*>(_%1$s_%2$s), NULL, "
-					"_%1$s_%2$s_ncomponents, 1, \n"
-					"                                         FFTW_FORWARD, 0%3$s);\n",
-					myName.c_str(), pXMLString->c_str(), useMeasureStr);
-		}
+    list<XMLString> vectorNamesList;
+    // get the names of all vectors in this field
+    vectorNames(vectorNamesList);
+    for (list<XMLString>::const_iterator
+       pXMLString = vectorNamesList.begin();
+       pXMLString != vectorNamesList.end();
+       pXMLString++) {
+      const xmdsVector *nextVector;
+      getVector(*pXMLString, nextVector);
+      if (!nextVector->needsFFTWRoutines()) {
+        continue;
+      }
+      fprintf(outfile,
+          "_%1$s_%2$s_forward_plan = fftw_plan_many_dft(_%1$s_ndims, "
+          "_fftw_lattice, _%1$s_%2$s_ncomponents, \n"
+          "                                         "
+          "reinterpret_cast<fftw_complex*>(_%1$s_%2$s), NULL, "
+          "_%1$s_%2$s_ncomponents, 1, \n"
+          "                                         "
+          "reinterpret_cast<fftw_complex*>(_%1$s_%2$s), NULL, "
+          "_%1$s_%2$s_ncomponents, 1, \n"
+          "                                         FFTW_FORWARD, 0%3$s);\n",
+          myName.c_str(), pXMLString->c_str(), useMeasureStr);
+    }
     }
 
     fprintf(outfile, "printf(\"Making backward plan\\n\");\n");
@@ -1253,30 +1253,30 @@ void xmdsField::writePlanCreationCalls(
           myName.c_str(), myName.c_str(), useMeasureStr, useWisdomStr);
     }
     else if (simulation()->parameters()->fftwVersion == 3) {
-		list<XMLString> vectorNamesList;
-		// get the names of all vectors in this field
-		vectorNames(vectorNamesList);
-		for (list<XMLString>::const_iterator
-			 pXMLString = vectorNamesList.begin();
-			 pXMLString != vectorNamesList.end();
-			 pXMLString++) {
-			const xmdsVector *nextVector;
-			getVector(*pXMLString, nextVector);
-			if (nextVector->needsFFTWRoutines()) {
-				fprintf(outfile,
-						"_%1$s_%2$s_backward_plan = fftw_plan_many_dft(_%1$s_ndims, "
-						"_fftw_lattice, _%1$s_%2$s_ncomponents, \n"
-						"                                         "
-						"reinterpret_cast<fftw_complex*>(_%1$s_%2$s), NULL, "
-						"_%1$s_%2$s_ncomponents, 1, \n"
-						"                                         "
-						"reinterpret_cast<fftw_complex*>(_%1$s_%2$s), NULL, "
-						"_%1$s_%2$s_ncomponents, 1, \n"
-						"                                         "
-						"FFTW_BACKWARD, 0%3$s);\n",
-						myName.c_str(), pXMLString->c_str(), useMeasureStr);
-			}
-		}
+    list<XMLString> vectorNamesList;
+    // get the names of all vectors in this field
+    vectorNames(vectorNamesList);
+    for (list<XMLString>::const_iterator
+       pXMLString = vectorNamesList.begin();
+       pXMLString != vectorNamesList.end();
+       pXMLString++) {
+      const xmdsVector *nextVector;
+      getVector(*pXMLString, nextVector);
+      if (nextVector->needsFFTWRoutines()) {
+        fprintf(outfile,
+            "_%1$s_%2$s_backward_plan = fftw_plan_many_dft(_%1$s_ndims, "
+            "_fftw_lattice, _%1$s_%2$s_ncomponents, \n"
+            "                                         "
+            "reinterpret_cast<fftw_complex*>(_%1$s_%2$s), NULL, "
+            "_%1$s_%2$s_ncomponents, 1, \n"
+            "                                         "
+            "reinterpret_cast<fftw_complex*>(_%1$s_%2$s), NULL, "
+            "_%1$s_%2$s_ncomponents, 1, \n"
+            "                                         "
+            "FFTW_BACKWARD, 0%3$s);\n",
+            myName.c_str(), pXMLString->c_str(), useMeasureStr);
+      }
+    }
     }
 
     if (useWisdom) {
@@ -1295,47 +1295,47 @@ void xmdsField::writePlanCreationCalls(
 // **************************************************************************
 void xmdsField::writePlanDeletionCalls(
                                        FILE *const outfile) const {
-	if (debugFlag) {
-		printf("xmdsField::writePlanDeletionCalls\n");
-	}
-	
-	if (!myNeedsFFTWPlans) {
-		return;
-	}
-	
-	if ((!(simulation()->parameters()->stochastic)) &
-		(simulation()->parameters()->usempi)) {
-		fprintf(outfile,
-				"fftwnd_mpi_destroy_plan(_%1$s_forward_plan);\n"
-				"fftwnd_mpi_destroy_plan(_%1$s_backward_plan);\n",
-				myName.c_str());
-	}
-	else if (simulation()->parameters()->fftwVersion == 2) {
-		fprintf(outfile,
-				"fftwnd_destroy_plan(_%1$s_forward_plan);\n"
-				"fftwnd_destroy_plan(_%1$s_backward_plan);\n",
-				myName.c_str());
-	}
-	else if (simulation()->parameters()->fftwVersion == 3) {
-		list<XMLString> vectorNamesList;
-		vectorNames(vectorNamesList);
-		for (list<XMLString>::const_iterator
-			 pXMLString = vectorNamesList.begin();
-			 pXMLString != vectorNamesList.end();
-			 pXMLString++) {
-			const xmdsVector *nextVector;
-			getVector(*pXMLString, nextVector);
-			if (!nextVector->needsFFTWRoutines()) {
-				continue;
-			}
-			fprintf(outfile,
-					"fftw_destroy_plan(_%1$s_%2$s_forward_plan);\n"
-					"fftw_destroy_plan(_%1$s_%2$s_backward_plan);\n",
-					myName.c_str(), pXMLString->c_str());
-		}
-	}
-	fprintf(outfile, "\n");
-									   }
+  if (debugFlag) {
+    printf("xmdsField::writePlanDeletionCalls\n");
+  }
+  
+  if (!myNeedsFFTWPlans) {
+    return;
+  }
+  
+  if ((!(simulation()->parameters()->stochastic)) &
+    (simulation()->parameters()->usempi)) {
+    fprintf(outfile,
+        "fftwnd_mpi_destroy_plan(_%1$s_forward_plan);\n"
+        "fftwnd_mpi_destroy_plan(_%1$s_backward_plan);\n",
+        myName.c_str());
+  }
+  else if (simulation()->parameters()->fftwVersion == 2) {
+    fprintf(outfile,
+        "fftwnd_destroy_plan(_%1$s_forward_plan);\n"
+        "fftwnd_destroy_plan(_%1$s_backward_plan);\n",
+        myName.c_str());
+  }
+  else if (simulation()->parameters()->fftwVersion == 3) {
+    list<XMLString> vectorNamesList;
+    vectorNames(vectorNamesList);
+    for (list<XMLString>::const_iterator
+       pXMLString = vectorNamesList.begin();
+       pXMLString != vectorNamesList.end();
+       pXMLString++) {
+      const xmdsVector *nextVector;
+      getVector(*pXMLString, nextVector);
+      if (!nextVector->needsFFTWRoutines()) {
+        continue;
+      }
+      fprintf(outfile,
+          "fftw_destroy_plan(_%1$s_%2$s_forward_plan);\n"
+          "fftw_destroy_plan(_%1$s_%2$s_backward_plan);\n",
+          myName.c_str(), pXMLString->c_str());
+    }
+  }
+  fprintf(outfile, "\n");
+                     }
 
 // **************************************************************************
 xmdsVector* xmdsField::createxmdsVector() {
@@ -1407,74 +1407,74 @@ void xmdsField::writeDefines(
 // **************************************************************************
 void xmdsField::writeGlobals(
                              FILE *const outfile) const {
-	if (debugFlag) {
-		printf("xmdsField::writeGlobals\n");
-	}
-	
-	fprintf(outfile,
-			"// ********************************************************\n"
-			"// field %s globals\n"
-			"\n",
-			myName.c_str());
-	
-	if (myGeometry.nDims() > 0) {
-		fprintf(outfile, "const unsigned long _%s_size = _%s_lattice0",
-				myName.c_str(), myName.c_str());
-		for (unsigned long i = 1; i < myGeometry.nDims(); i++) {
-			fprintf(outfile, "*_%s_lattice%li", myName.c_str(), i);
-		}
-		fprintf(outfile, ";\n");
-	}
-	else {
-		fprintf(outfile, "const unsigned long _%s_size = 1;\n", myName.c_str());
-	}
-	fprintf(outfile, "\n");
-	
-	if (myNeedsFFTWPlans) {
-		if ((!(simulation()->parameters()->stochastic)) &
-			(simulation()->parameters()->usempi)) {
-			fprintf(outfile,
-					"fftwnd_mpi_plan _%1$s_forward_plan;\n"
-					"fftwnd_mpi_plan _%1$s_backward_plan;\n",
-					myName.c_str());
-		}
-		else if (simulation()->parameters()->fftwVersion == 2) {
-			fprintf(outfile,
-					"fftwnd_plan _%1$s_forward_plan;\n"
-					"fftwnd_plan _%1$s_backward_plan;\n",
-					myName.c_str());
-		}
-		else if (simulation()->parameters()->fftwVersion == 3) {
-			list<XMLString> vectorNamesList;
-			vectorNames(vectorNamesList);
-			for (list<XMLString>::const_iterator
-				 pXMLString = vectorNamesList.begin();
-				 pXMLString != vectorNamesList.end();
-				 pXMLString++) {
-				const xmdsVector *nextVector;
-				getVector(*pXMLString, nextVector);
-				if (!nextVector->needsFFTWRoutines()) {
-					continue;
-				}
-				fprintf(outfile,
-						"fftw_plan _%1$s_%2$s_forward_plan;\n"
-						"fftw_plan _%1$s_%2$s_backward_plan;\n",
-						myName.c_str(), pXMLString->c_str());
-			}
-		}
-	}
-	
-	fprintf(outfile, "\n");
-	
-	for (list<const xmdsVector*>::const_iterator
-		 ppxmdsVector = myVectorsList.begin();
-		 ppxmdsVector != myVectorsList.end();
-		 ppxmdsVector++) {
-		(*ppxmdsVector)->writeGlobals(outfile);
-	}
-	
-	fprintf(outfile, "\n");
-							 }
+  if (debugFlag) {
+    printf("xmdsField::writeGlobals\n");
+  }
+  
+  fprintf(outfile,
+      "// ********************************************************\n"
+      "// field %s globals\n"
+      "\n",
+      myName.c_str());
+  
+  if (myGeometry.nDims() > 0) {
+    fprintf(outfile, "const unsigned long _%s_size = _%s_lattice0",
+        myName.c_str(), myName.c_str());
+    for (unsigned long i = 1; i < myGeometry.nDims(); i++) {
+      fprintf(outfile, "*_%s_lattice%li", myName.c_str(), i);
+    }
+    fprintf(outfile, ";\n");
+  }
+  else {
+    fprintf(outfile, "const unsigned long _%s_size = 1;\n", myName.c_str());
+  }
+  fprintf(outfile, "\n");
+  
+  if (myNeedsFFTWPlans) {
+    if ((!(simulation()->parameters()->stochastic)) &
+      (simulation()->parameters()->usempi)) {
+      fprintf(outfile,
+          "fftwnd_mpi_plan _%1$s_forward_plan;\n"
+          "fftwnd_mpi_plan _%1$s_backward_plan;\n",
+          myName.c_str());
+    }
+    else if (simulation()->parameters()->fftwVersion == 2) {
+      fprintf(outfile,
+          "fftwnd_plan _%1$s_forward_plan;\n"
+          "fftwnd_plan _%1$s_backward_plan;\n",
+          myName.c_str());
+    }
+    else if (simulation()->parameters()->fftwVersion == 3) {
+      list<XMLString> vectorNamesList;
+      vectorNames(vectorNamesList);
+      for (list<XMLString>::const_iterator
+         pXMLString = vectorNamesList.begin();
+         pXMLString != vectorNamesList.end();
+         pXMLString++) {
+        const xmdsVector *nextVector;
+        getVector(*pXMLString, nextVector);
+        if (!nextVector->needsFFTWRoutines()) {
+          continue;
+        }
+        fprintf(outfile,
+            "fftw_plan _%1$s_%2$s_forward_plan;\n"
+            "fftw_plan _%1$s_%2$s_backward_plan;\n",
+            myName.c_str(), pXMLString->c_str());
+      }
+    }
+  }
+  
+  fprintf(outfile, "\n");
+  
+  for (list<const xmdsVector*>::const_iterator
+     ppxmdsVector = myVectorsList.begin();
+     ppxmdsVector != myVectorsList.end();
+     ppxmdsVector++) {
+    (*ppxmdsVector)->writeGlobals(outfile);
+  }
+  
+  fprintf(outfile, "\n");
+               }
 
 // **************************************************************************
 void xmdsField::writePrototypes(
