@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: xmds_integrate_ark45.cc 1640 2008-01-10 00:11:32Z joehope $
+  $Id: xmds_integrate_ark45.cc 1964 2008-04-09 00:42:11Z paultcochrane $
 */
 
 /*! @file xmds_integrate_ark45.cc
@@ -35,6 +35,7 @@
 #include <xmds_simulation.h>
 #include <xmds_vector.h>
 #include <cstdlib>
+#include <cstring>
 
 // **************************************************************************
 // **************************************************************************
@@ -289,21 +290,21 @@ void xmdsIntegrateARK45::writeTimestepErrorRoutine(
       fprintf(outfile, "for(unsigned long _i0=0; _i0<_%s_size; _i0++){\n", fieldName);
     }
     fprintf(outfile, "   for(unsigned long _i1=0; _i1<_%s_main_ncomponents; _i1++){\n", fieldName);
-    if (strcmp(typeName, "complex") == 0) {
+    if (std::strcmp(typeName, "complex") == 0) {
       fprintf(outfile, "    _temp_mod=mod2(_%s_main[_%s_main_index_pointer + _i1]);\n", fieldName, fieldName);
     }
     else {
       fprintf(outfile, "    _temp_mod=fabs(_%s_main[_%s_main_index_pointer + _i1]);\n", fieldName, fieldName);
     }
-    // this construction will add zero if field(x)<peak and correct peak to 
+    // this construction will add zero if field(x)<peak and correct peak to
     // its new value if field(x)>peak
 
-    /* this construction was 
+    /* this construction was
      * _peak[_i1] += 0.5*(_temp_mod - _peak[_i1] + fabs(_temp_mod - _peak[_i1]));
-     * It was a bad idea because it leads to NaNs for the peak value when it 
-     * should be infinite, because it tries to add values to Inf, leading to 
-     * NaN. The other problem with this construction is that it requires a 
-     * store on each loop which will be slower than a branch (particularly 
+     * It was a bad idea because it leads to NaNs for the peak value when it
+     * should be infinite, because it tries to add values to Inf, leading to
+     * NaN. The other problem with this construction is that it requires a
+     * store on each loop which will be slower than a branch (particularly
      * when that branch is predicted correctly as it will be by modern CPUs).
      */
     fprintf(outfile,
@@ -324,7 +325,7 @@ void xmdsIntegrateARK45::writeTimestepErrorRoutine(
           "}\n");
     }
 
-    // now the peak value is multiplied with the cutoff so that it is now in 
+    // now the peak value is multiplied with the cutoff so that it is now in
     // fact the amplitude-threshold for error determination
     fprintf(outfile, "for(unsigned long _i0=0; _i0<_%s_main_ncomponents; _i0++) {\n", fieldName);
     fprintf(outfile,
@@ -347,13 +348,13 @@ void xmdsIntegrateARK45::writeTimestepErrorRoutine(
     }
     fprintf(outfile, "   for(unsigned long _i1=0; _i1<_%s_main_ncomponents; _i1++)\n", fieldName);
 
-    if (strcmp(typeName, "complex") == 0) {
+    if (std::strcmp(typeName, "complex") == 0) {
       fprintf(outfile, "       if(mod2(_%s_main[_%s_main_index_pointer + _i1])>_peak[_i1]){\n", fieldName, fieldName);
-      fprintf(outfile, "            _temp_error=mod(_%s_main[_%s_main_index_pointer + _i1]-_checkfield[_%s_main_index_pointer + _i1])/mod(_%s_main[_%s_main_index_pointer + _i1]);\n", fieldName, fieldName, fieldName, fieldName, fieldName);
+      fprintf(outfile, "            _temp_error=mod(_%s_main[_%s_main_index_pointer + _i1]-_checkfield[_%s_main_index_pointer + _i1])/(mod(_%s_main[_%s_main_index_pointer + _i1])+1e-20);\n", fieldName, fieldName, fieldName, fieldName, fieldName);
     }
     else{
       fprintf(outfile, "       if(fabs(_%s_main[_%s_main_index_pointer + _i1])>_peak[_i1]){\n", fieldName, fieldName);
-      fprintf(outfile, "            _temp_error=fabs(_%s_main[_%s_main_index_pointer + _i1]-_checkfield[_%s_main_index_pointer + _i1])/fabs(_%s_main[_%s_main_index_pointer + _i1]);\n", fieldName, fieldName, fieldName, fieldName, fieldName);
+      fprintf(outfile, "            _temp_error=fabs(_%s_main[_%s_main_index_pointer + _i1]-_checkfield[_%s_main_index_pointer + _i1])/(fabs(_%s_main[_%s_main_index_pointer + _i1])+1e-20);\n", fieldName, fieldName, fieldName, fieldName, fieldName);
     }
     fprintf(outfile, "            if (_error < _temp_error) _error = _temp_error;\n");
     fprintf(outfile, "       }\n");
@@ -364,11 +365,11 @@ void xmdsIntegrateARK45::writeTimestepErrorRoutine(
   else{ // if ndims==0
     fprintf(outfile, "   for(unsigned long _i1=0; _i1<_%s_main_ncomponents; _i1++){\n", fieldName);
 
-    if (strcmp(typeName, "complex") == 0) {
-      fprintf(outfile, "       _temp_error=mod(_%s_main[_i1]-_checkfield[_i1])/mod(_%s_main[_i1]);\n", fieldName, fieldName);
+    if (std::strcmp(typeName, "complex") == 0) {
+      fprintf(outfile, "       _temp_error=mod(_%s_main[_i1]-_checkfield[_i1])/(mod(_%s_main[_i1])+1e-20);\n", fieldName, fieldName);
     }
     else{
-      fprintf(outfile, "       _temp_error=fabs(_%s_main[_i1]-_checkfield[_i1])/fabs(_%s_main[_i1]);\n", fieldName, fieldName);
+      fprintf(outfile, "       _temp_error=fabs(_%s_main[_i1]-_checkfield[_i1])/(fabs(_%s_main[_i1])+1e-20);\n", fieldName, fieldName);
     }
     fprintf(outfile, "       if (_error < _temp_error) _error = _temp_error;\n");
     fprintf(outfile, "    }\n");
@@ -419,10 +420,10 @@ void xmdsIntegrateARK45::writeSetupSamplingRoutine(FILE *const outfile) const
   fprintf(outfile, "    _next_sample_flag[_i0]=false;\n");
   fprintf(outfile, "\n");
 
-  // check if moment group needs sampling at the same time as another, 
-  // already discovered sample (or the final time). If so, add this moment 
-  // group to the to-be-sampled-list. If moment group demands sampling 
-  // earlier than all previously noted mg's erase all previous ones from 
+  // check if moment group needs sampling at the same time as another,
+  // already discovered sample (or the final time). If so, add this moment
+  // group to the to-be-sampled-list. If moment group demands sampling
+  // earlier than all previously noted mg's erase all previous ones from
   // list and set the brekpoint-time to this earlier one.
   for (unsigned long i=0; i<simulation()->output()->nMomentGroups(); i++) {
     if (samples(i) != 0) {
@@ -433,12 +434,12 @@ void xmdsIntegrateARK45::writeSetupSamplingRoutine(FILE *const outfile) const
       fprintf(outfile, "else if(_next_sample_counter[%li]*_previous_M<_previous_m*%li){\n", i, samples(i));
     double temp_interval;
     // If the user specified a number, than we can compute some stuff now
-    if (interval()->asDouble(temp_interval)) {  
+    if (interval()->asDouble(temp_interval)) {
         fprintf(outfile, "    _%s_break_next=_next_sample_counter[%li]*%.23e;\n", propDim, i, temp_interval/samples(i));
     }
-    // If the user specified something else (probably a const double in 
+    // If the user specified something else (probably a const double in
     // <globals>), then we need to let the compiler do it or do it at run time...
-    else {  
+    else {
     fprintf(outfile, "    _%s_break_next=_next_sample_counter[%li]*%s/%lu;\n", propDim, i, interval()->c_str(), samples(i));
     }
       fprintf(outfile, "    _number_minima=1;\n");
@@ -449,8 +450,8 @@ void xmdsIntegrateARK45::writeSetupSamplingRoutine(FILE *const outfile) const
     }
   }
   fprintf(outfile, "\n");
-  // Values of _number_next_mg until _number_minima contain now the complete 
-  // list of mg's that need to be sampled at the next breakpoint. Set their 
+  // Values of _number_next_mg until _number_minima contain now the complete
+  // list of mg's that need to be sampled at the next breakpoint. Set their
   // flags to true.
   fprintf(outfile, "for(unsigned long _i0=0; _i0<_number_minima; _i0++)\n");
   fprintf(outfile, "   _next_sample_flag[_number_next_mg[_i0]]=true;\n");
@@ -517,16 +518,16 @@ void xmdsIntegrateARK45::writeMainIntegrateRoutine(FILE *const outfile) const
   fprintf(outfile, "\n");
   if (simulation()->parameters()->stochastic &&
       !noNoises()) {
-	  fprintf(outfile, "const double _var = 1");
-	  for (unsigned long i=0; i<simulation()->field()->geometry()->nDims(); i++) {
-		  fprintf(outfile, "/_%s_dx%li", fieldName, i);
-	  }
-	  fprintf(outfile, ";\n");
-	  fprintf(outfile, "double *_noise_vector = new double[_%s_size*_n_noises];\n", fieldName);
-	  if (simulation()->parameters()->errorCheck) {
-		  fprintf(outfile, "double *_noise_vector2 = new double[_%s_size*_n_noises];\n", fieldName);
-	  }
-	  fprintf(outfile, "\n");
+    fprintf(outfile, "const double _var = 1");
+    for (unsigned long i=0; i<simulation()->field()->geometry()->nDims(); i++) {
+      fprintf(outfile, "/_%s_dx%li", fieldName, i);
+    }
+    fprintf(outfile, ";\n");
+    fprintf(outfile, "double *_noise_vector = new double[_%s_size*_n_noises];\n", fieldName);
+    if (simulation()->parameters()->errorCheck) {
+      fprintf(outfile, "double *_noise_vector2 = new double[_%s_size*_n_noises];\n", fieldName);
+    }
+    fprintf(outfile, "\n");
   }
 
   fprintf(outfile,
@@ -694,8 +695,6 @@ void xmdsIntegrateARK45::writeMainIntegrateRoutine(FILE *const outfile) const
   fprintf(outfile, "do{\n    do{\n");
   fprintf(outfile, "\n");
 
-  writeRuntimeCheckingCode(outfile);
-
   if (simulation()->parameters()->stochastic &&
       !noNoises()) {
 
@@ -722,14 +721,17 @@ void xmdsIntegrateARK45::writeMainIntegrateRoutine(FILE *const outfile) const
 
   fprintf(outfile, "\n");
 
+  // Check if we need to halt before we try the next time-step,
+  // and before we reset the segment.
+  writeHaltCheckingCode(outfile);
+
   fprintf(outfile, "    _error=_segment%li_timestep_error(_%s_check);\n", segmentNumber, fieldName);
   fprintf(outfile, "\n");
   fprintf(outfile, "    if(_error<_tolerance){;\n");
   fprintf(outfile, "        if(_step>_max_step)\n");
   fprintf(outfile, "             _max_step=_step;\n");
-  fprintf(outfile, "        if(!_break_next)\n");
-  fprintf(outfile, "             if(_step<_min_step)\n");
-  fprintf(outfile, "                 _min_step=_step;\n");
+  fprintf(outfile, "        if(!_break_next && _step < _min_step)\n");
+  fprintf(outfile, "             _min_step=_step;\n");
   fprintf(outfile, "        _step*=0.92*pow(fabs(_tolerance/_error), 0.2);\n");
   fprintf(outfile, "        _discard=false;\n");
   fprintf(outfile, "        }\n");
@@ -739,6 +741,11 @@ void xmdsIntegrateARK45::writeMainIntegrateRoutine(FILE *const outfile) const
   fprintf(outfile, "        _discard=true;\n");
   fprintf(outfile, "        _break_next=false;\n");
   fprintf(outfile, "        _segment%li_reset(_aifield_%s_main, _step);\n", segmentNumber, fieldName);
+
+  // We only check step-size when error is intolerable,
+  // so there is no cost when the integration is running successfully.
+  writeStepCheckingCode(outfile);
+
   fprintf(outfile, "        }\n");
 
   if (max_iter){
@@ -753,6 +760,7 @@ void xmdsIntegrateARK45::writeMainIntegrateRoutine(FILE *const outfile) const
 
   fprintf(outfile, "    }while(_discard);\n");
 
+  // We have now accepted the time-step
 
   fprintf(outfile, "\n");
   fprintf(outfile, "    if(_break_next){\n");
@@ -788,8 +796,8 @@ void xmdsIntegrateARK45::writeMainIntegrateRoutine(FILE *const outfile) const
   fprintf(outfile, "}while(!_next_sample_flag[%li]);\n", simulation()->output()->nMomentGroups()+1);
   fprintf(outfile, "\n");
 
-  if (simulation()->parameters()->runTimeLimit > 0.0)
-    fprintf(outfile, "_SEGMENT%li_END:\n", segmentNumber);
+  // This label is used in the halt checking code
+  fprintf(outfile, "_SEGMENT%li_END:\n", segmentNumber);
 
   if (simulation()->parameters()->nPaths == "1") {
     // Don't print lots of stuff for each path, because we're running lots of them.
