@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: xmds_integrate_ark89.cc 1630 2007-12-21 18:51:09Z paultcochrane $
+  $Id: xmds_integrate_ark89.cc 1964 2008-04-09 00:42:11Z paultcochrane $
 */
 
 /*! @file xmds_integrate_ark89.cc
@@ -35,6 +35,7 @@
 #include <xmds_simulation.h>
 #include <xmds_vector.h>
 #include <cstdlib>
+#include <cstring>
 
 // **************************************************************************
 // **************************************************************************
@@ -284,7 +285,7 @@ void xmdsIntegrateARK89::writeTimestepErrorRoutine(
       fprintf(outfile, "for (unsigned long _i0=0; _i0<_%s_size; _i0++){\n", fieldName);
     }
     fprintf(outfile, "   for (unsigned long _i1=0; _i1<_%s_main_ncomponents; _i1++){\n", fieldName);
-    if (strcmp(typeName, "complex") == 0) {
+    if (std::strcmp(typeName, "complex") == 0) {
       fprintf(outfile, "    _temp_mod=mod2(_%s_main[_%s_main_index_pointer + _i1]);\n", fieldName, fieldName);
     }
     else {
@@ -334,13 +335,13 @@ void xmdsIntegrateARK89::writeTimestepErrorRoutine(
     }
     fprintf(outfile, "   for (unsigned long _i1=0; _i1<_%s_main_ncomponents; _i1++)\n", fieldName);
 
-    if (strcmp(typeName, "complex") == 0) {
+    if (std::strcmp(typeName, "complex") == 0) {
       fprintf(outfile, "       if (mod2(_%s_main[_%s_main_index_pointer + _i1])>_peak[_i1]){\n", fieldName, fieldName);
-      fprintf(outfile, "            _temp_error=mod(_%s_main[_%s_main_index_pointer + _i1]-_checkfield[_%s_main_index_pointer + _i1])/mod(_%s_main[_%s_main_index_pointer + _i1]);\n", fieldName, fieldName, fieldName, fieldName, fieldName);
+      fprintf(outfile, "            _temp_error=mod(_%s_main[_%s_main_index_pointer + _i1]-_checkfield[_%s_main_index_pointer + _i1])/(mod(_%s_main[_%s_main_index_pointer + _i1])+1e-20);\n", fieldName, fieldName, fieldName, fieldName, fieldName);
     }
     else{
       fprintf(outfile, "       if (fabs(_%s_main[_%s_main_index_pointer + _i1])>_peak[_i1]){\n", fieldName, fieldName);
-      fprintf(outfile, "            _temp_error=fabs(_%s_main[_%s_main_index_pointer + _i1]-_checkfield[_%s_main_index_pointer + _i1])/fabs(_%s_main[_%s_main_index_pointer + _i1]);\n", fieldName, fieldName, fieldName, fieldName, fieldName);
+      fprintf(outfile, "            _temp_error=fabs(_%s_main[_%s_main_index_pointer + _i1]-_checkfield[_%s_main_index_pointer + _i1])/(fabs(_%s_main[_%s_main_index_pointer + _i1])+1e-20);\n", fieldName, fieldName, fieldName, fieldName, fieldName);
     }
     fprintf(outfile, "            if (_error < _temp_error) _error = _temp_error;\n");
     fprintf(outfile, "       }\n");
@@ -352,11 +353,11 @@ void xmdsIntegrateARK89::writeTimestepErrorRoutine(
 
     fprintf(outfile, "   for (unsigned long _i1=0; _i1<_%s_main_ncomponents; _i1++){\n", fieldName);
 
-    if (strcmp(typeName, "complex") == 0){
-      fprintf(outfile, "       _temp_error=mod(_%s_main[_i1]-_checkfield[_i1])/mod(_%s_main[_i1]);\n", fieldName, fieldName);
+    if (std::strcmp(typeName, "complex") == 0){
+      fprintf(outfile, "       _temp_error=mod(_%s_main[_i1]-_checkfield[_i1])/(mod(_%s_main[_i1])+1e-20);\n", fieldName, fieldName);
     }
     else{
-      fprintf(outfile, "       _temp_error=fabs(_%s_main[_i1]-_checkfield[_i1])/fabs(_%s_main[_i1]);\n", fieldName, fieldName);
+      fprintf(outfile, "       _temp_error=fabs(_%s_main[_i1]-_checkfield[_i1])/(fabs(_%s_main[_i1])+1e-20);\n", fieldName, fieldName);
     }
     fprintf(outfile, "       if (_error < _temp_error) _error = _temp_error;\n");
     fprintf(outfile, "    }\n");
@@ -707,8 +708,6 @@ void xmdsIntegrateARK89::writeMainIntegrateRoutine(FILE *const outfile) const
   fprintf(outfile, "do{\n    do{\n");
   fprintf(outfile, "\n");
 
-  writeRuntimeCheckingCode(outfile);
-
   if ((simulation()->parameters()->stochastic)&&(!noNoises())) {
 
     fprintf(outfile, "if (_noise_list.empty()) { \n");
@@ -759,6 +758,10 @@ void xmdsIntegrateARK89::writeMainIntegrateRoutine(FILE *const outfile) const
 
   fprintf(outfile, "\n");
 
+  // Check if we need to halt before we try the next time-step,
+  // and before we reset the segment.
+  writeHaltCheckingCode(outfile);
+
   fprintf(outfile, "    _error=_segment%li_timestep_error(_akafield_%s_main);\n", segmentNumber, fieldName);
   fprintf(outfile, "\n");
   fprintf(outfile, "    if (_error<_tolerance){;\n");
@@ -783,9 +786,8 @@ void xmdsIntegrateARK89::writeMainIntegrateRoutine(FILE *const outfile) const
   }
   fprintf(outfile, "        if (_step>_max_step)\n");
   fprintf(outfile, "             _max_step=_step;\n");
-  fprintf(outfile, "        if (!_break_next)\n");
-  fprintf(outfile, "             if (_step<_min_step)\n");
-  fprintf(outfile, "                 _min_step=_step;\n");
+  fprintf(outfile, "        if (!_break_next && _step < _min_step)\n");
+  fprintf(outfile, "             _min_step=_step;\n");
   if ((simulation()->parameters()->stochastic)&&(!noNoises())) {
     fprintf(outfile, "        _step*=0.92*pow(fabs(_tolerance/_error), 0.2);\n");
   }
@@ -805,6 +807,11 @@ void xmdsIntegrateARK89::writeMainIntegrateRoutine(FILE *const outfile) const
   fprintf(outfile, "        _discard=true;\n");
   fprintf(outfile, "        _break_next=false;\n");
   fprintf(outfile, "        _segment%li_reset(_%s_init, _step);\n", segmentNumber, fieldName);
+
+  // We only check step-size when error is intolerable,
+  // so there is no cost when the integration is running successfully.
+  writeStepCheckingCode(outfile);
+
   fprintf(outfile, "        }\n");
 
   if (max_iter){
@@ -819,6 +826,7 @@ void xmdsIntegrateARK89::writeMainIntegrateRoutine(FILE *const outfile) const
 
   fprintf(outfile, "    }while (_discard);\n");
 
+  // We have now accepted the timestep
 
   fprintf(outfile, "\n");
   fprintf(outfile, "    if (_break_next){\n");
@@ -856,8 +864,8 @@ void xmdsIntegrateARK89::writeMainIntegrateRoutine(FILE *const outfile) const
   fprintf(outfile, "}while (!_next_sample_flag[%li]);\n", simulation()->output()->nMomentGroups()+1);
   fprintf(outfile, "\n");
 
-  if (simulation()->parameters()->runTimeLimit > 0.0)
-    fprintf(outfile, "_SEGMENT%li_END:\n", segmentNumber);
+  // This label is used in the halt checking code
+  fprintf(outfile, "_SEGMENT%li_END:\n", segmentNumber);
 
   if (simulation()->parameters()->nPaths=="1") {
     if (simulation()->parameters()->usempi)
