@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: xmds_integrate_ex.cc 1640 2008-01-10 00:11:32Z joehope $
+  $Id: xmds_integrate_ex.cc 1924 2008-03-28 02:23:27Z grahamdennis $
 */
 
 /*! @file xmds_integrate_ex.cc
@@ -124,7 +124,7 @@ void xmdsIntegrateEX::processElement(
           printf("adding operator-component pair: %s[%s]\n", nextOperatorName.c_str(), nextComponentName.c_str());
         }
 
-		unsigned long cLength =  mainVector->componentLength(nextComponentNumber);
+    unsigned long cLength =  mainVector->componentLength(nextComponentNumber);
         coKey = addcoPair(nextComponentNumber, nextOperatorNumber, cLength);
 
         coVectorComponentNamesList.push_back(nextVectorComponentName);
@@ -164,8 +164,8 @@ void xmdsIntegrateEX::processElement(
     simulation()->field()->processVectors(tempVectorNamesList, simulation()->field()->geometry()->fullSpace());
 
     vectorNamesList()->push_back(s);
-	
-	if (verbose()) {
+  
+  if (verbose()) {
           printf("Number of components in %s: %li\n", s, coVectorComponentNamesList.size());
         }
 
@@ -247,11 +247,8 @@ void xmdsIntegrateEX::writeCalculatekOperatorFieldRoutine(
   simulation()->field()->vectors2space(outfile, fullSpace, *KVectorNamesList(), "");
 
   fprintf(outfile, "unsigned long _k_operator_index_pointer=0;\n");
-  list<XMLString> tempVectorNamesList = *KVectorNamesList();
-  tempVectorNamesList.push_back("_k_operator_index_pointer");
-  threadPrivateVariables.push_back("_k_operator_index_pointer");
 
-  simulation()->field()->openLoops(outfile, fullSpace, *KVectorNamesList(), PARALLELISE_LOOP, threadPrivateVariables);
+  simulation()->field()->openLoops(outfile, fullSpace, *KVectorNamesList(), DO_NOT_PARALLELISE_LOOP);
 
   char indent[64];
   for (i=0; i<nDims; i++) {
@@ -319,70 +316,70 @@ void xmdsIntegrateEX::writeCalculateCOTermsConstantKRoutine(
   fprintf(outfile, "\n");
 
   for (unsigned long i=0; i<mainVector->nComponents(); i++) {
-	  
-	  const coStruct* thecoStruct;
-	  
-	  if (getcoStruct(i, thecoStruct)) {
-		  
-		  unsigned long previousComponents = 0;
-		  for(unsigned long componentCounter = 0; componentCounter<i; componentCounter++) {
-			  previousComponents+=mainVector->componentLength(componentCounter);
-		  }
-		  
-		  list<unsigned long>::const_iterator pULong1 = thecoStruct->operatorNumbersList.begin();
-		  list<unsigned long>::const_iterator pULong2 = thecoStruct->coKeysList.begin();
-		  
-		  while (pULong1 != thecoStruct->operatorNumbersList.end()) {
-			  
-			  if(mainVector->componentLength(i)>1) {
-				  fprintf(outfile, "\n");
-				  fprintf(outfile, " for(unsigned long _j = 0; _j<%li; _j++) {\n",mainVector->componentLength(i));
-				  fprintf(outfile, "   _temp = _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].re\n",
-						  segmentNumber, segmentNumber, *pULong1);
-				  fprintf(outfile, "         *_active_%s_main[_active_%s_index_pointer + _j + %li].re\n", fieldName, fieldName, previousComponents);
-				  fprintf(outfile, "         - _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].im\n",
-						  segmentNumber, segmentNumber, *pULong1);
-				  fprintf(outfile, "         *_active_%s_main[_active_%s_index_pointer + _j + %li].im;\n", fieldName, fieldName, previousComponents);
-				  fprintf(outfile, "\n");
-				  fprintf(outfile, "   _%s_segment%li_co_terms[_%s_segment_%li_co_terms_index_pointer + _j + %li].im =\n",
-						  fieldName, segmentNumber, fieldName, segmentNumber, *pULong2);
-				  fprintf(outfile, "        _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].re\n",
-						  segmentNumber, segmentNumber, *pULong1);
-				  fprintf(outfile, "       *_active_%s_main[_active_%s_index_pointer + _j + %li].im\n", fieldName, fieldName, previousComponents);
-				  fprintf(outfile, "      + _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].im\n",
-						  segmentNumber, segmentNumber, *pULong1);
-				  fprintf(outfile, "       *_active_%s_main[_active_%s_index_pointer + _j + %li].re;\n", fieldName, fieldName, previousComponents);
-				  fprintf(outfile, "\n");
-				  fprintf(outfile, "   _%s_segment%li_co_terms[_%s_segment_%li_co_terms_index_pointer + _j + %li].re=_temp;\n",
-						  fieldName, segmentNumber, fieldName, segmentNumber, *pULong2);
-				  fprintf(outfile, "  }\n");
-			  }
-			  else {
-				  fprintf(outfile, "\n");
-				  fprintf(outfile, " _temp = _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].re\n",
-						  segmentNumber, segmentNumber, *pULong1);
-				  fprintf(outfile, "       *_active_%s_main[_active_%s_index_pointer + %li].re\n", fieldName, fieldName, previousComponents);
-				  fprintf(outfile, "       - _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].im\n",
-						  segmentNumber, segmentNumber, *pULong1);
-				  fprintf(outfile, "       *_active_%s_main[_active_%s_index_pointer + %li].im;\n", fieldName, fieldName, previousComponents);
-				  fprintf(outfile, "\n");
-				  fprintf(outfile, " _%s_segment%li_co_terms[_%s_segment_%li_co_terms_index_pointer + %li].im =\n",
-						  fieldName, segmentNumber, fieldName, segmentNumber, *pULong2);
-				  fprintf(outfile, "      _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].re\n",
-						  segmentNumber, segmentNumber, *pULong1);
-				  fprintf(outfile, "     *_active_%s_main[_active_%s_index_pointer + %li].im\n", fieldName, fieldName, previousComponents);
-				  fprintf(outfile, "    + _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].im\n",
-						  segmentNumber, segmentNumber, *pULong1);
-				  fprintf(outfile, "     *_active_%s_main[_active_%s_index_pointer + %li].re;\n", fieldName, fieldName, previousComponents);
-				  fprintf(outfile, "\n");
-				  fprintf(outfile, " _%s_segment%li_co_terms[_%s_segment_%li_co_terms_index_pointer + %li].re=_temp;\n",
-						  fieldName, segmentNumber, fieldName, segmentNumber, *pULong2);
-			  }
-			  
-			  pULong1++;
-			  pULong2++;
-		  }
-	  }
+
+    const coStruct* thecoStruct;
+
+    if (getcoStruct(i, thecoStruct)) {
+
+      unsigned long previousComponents = 0;
+      for (unsigned long componentCounter = 0; componentCounter<i; componentCounter++) {
+        previousComponents+=mainVector->componentLength(componentCounter);
+      }
+
+      list<unsigned long>::const_iterator pULong1 = thecoStruct->operatorNumbersList.begin();
+      list<unsigned long>::const_iterator pULong2 = thecoStruct->coKeysList.begin();
+
+      while (pULong1 != thecoStruct->operatorNumbersList.end()) {
+
+        if (mainVector->componentLength(i)>1) {
+          fprintf(outfile, "\n");
+          fprintf(outfile, " for (unsigned long _j = 0; _j<%li; _j++) {\n",mainVector->componentLength(i));
+          fprintf(outfile, "   _temp = _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].re\n",
+              segmentNumber, segmentNumber, *pULong1);
+          fprintf(outfile, "         *_active_%s_main[_active_%s_index_pointer + _j + %li].re\n", fieldName, fieldName, previousComponents);
+          fprintf(outfile, "         - _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].im\n",
+              segmentNumber, segmentNumber, *pULong1);
+          fprintf(outfile, "         *_active_%s_main[_active_%s_index_pointer + _j + %li].im;\n", fieldName, fieldName, previousComponents);
+          fprintf(outfile, "\n");
+          fprintf(outfile, "   _%s_segment%li_co_terms[_%s_segment_%li_co_terms_index_pointer + _j + %li].im =\n",
+              fieldName, segmentNumber, fieldName, segmentNumber, *pULong2);
+          fprintf(outfile, "        _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].re\n",
+              segmentNumber, segmentNumber, *pULong1);
+          fprintf(outfile, "       *_active_%s_main[_active_%s_index_pointer + _j + %li].im\n", fieldName, fieldName, previousComponents);
+          fprintf(outfile, "      + _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].im\n",
+              segmentNumber, segmentNumber, *pULong1);
+          fprintf(outfile, "       *_active_%s_main[_active_%s_index_pointer + _j + %li].re;\n", fieldName, fieldName, previousComponents);
+          fprintf(outfile, "\n");
+          fprintf(outfile, "   _%s_segment%li_co_terms[_%s_segment_%li_co_terms_index_pointer + _j + %li].re=_temp;\n",
+              fieldName, segmentNumber, fieldName, segmentNumber, *pULong2);
+          fprintf(outfile, "  }\n");
+        }
+        else {
+          fprintf(outfile, "\n");
+          fprintf(outfile, " _temp = _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].re\n",
+              segmentNumber, segmentNumber, *pULong1);
+          fprintf(outfile, "       *_active_%s_main[_active_%s_index_pointer + %li].re\n", fieldName, fieldName, previousComponents);
+          fprintf(outfile, "       - _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].im\n",
+              segmentNumber, segmentNumber, *pULong1);
+          fprintf(outfile, "       *_active_%s_main[_active_%s_index_pointer + %li].im;\n", fieldName, fieldName, previousComponents);
+          fprintf(outfile, "\n");
+          fprintf(outfile, " _%s_segment%li_co_terms[_%s_segment_%li_co_terms_index_pointer + %li].im =\n",
+              fieldName, segmentNumber, fieldName, segmentNumber, *pULong2);
+          fprintf(outfile, "      _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].re\n",
+              segmentNumber, segmentNumber, *pULong1);
+          fprintf(outfile, "     *_active_%s_main[_active_%s_index_pointer + %li].im\n", fieldName, fieldName, previousComponents);
+          fprintf(outfile, "    + _segment%li_k_operator_field[_segment%li_kop_index_pointer + %li].im\n",
+              segmentNumber, segmentNumber, *pULong1);
+          fprintf(outfile, "     *_active_%s_main[_active_%s_index_pointer + %li].re;\n", fieldName, fieldName, previousComponents);
+          fprintf(outfile, "\n");
+          fprintf(outfile, " _%s_segment%li_co_terms[_%s_segment_%li_co_terms_index_pointer + %li].re=_temp;\n",
+              fieldName, segmentNumber, fieldName, segmentNumber, *pULong2);
+        }
+
+        pULong1++;
+        pULong2++;
+      }
+    }
   }
 
   fprintf(outfile, "  _segment%li_kop_index_pointer+=_segment%li_nkoperators;\n", segmentNumber, segmentNumber);
