@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: xmds_integrate_ip.cc 1640 2008-01-10 00:11:32Z joehope $
+  $Id: xmds_integrate_ip.cc 1885 2008-03-18 15:24:56Z paultcochrane $
 */
 
 /*! @file xmds_integrate_ip.cc
@@ -124,11 +124,11 @@ void xmdsIntegrateIP::processElement(
 			  addcoPair(nextComponentNumber, nextOperatorNumber,dummyLong);
 		  }
 		  
-		  if(XMLChar::isWhiteSpace(propagationCode()->data(end))) {
-			  theCode->replaceData(start, end-start, "0");
+		  if(propagationCode()->data(end)=='(') {
+			  theCode->replaceData(start, end-start, "0*");
 		  }
 		  else {
-			  theCode->replaceData(start, end-start, "0*");
+			  theCode->replaceData(start, end-start, "0");
 		  }
 		  
 		  start = start+1;
