@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: xmds_integrate_rk4.cc 1599 2007-11-17 13:42:49Z paultcochrane $
+  $Id: xmds_integrate_rk4.cc 1885 2008-03-18 15:24:56Z paultcochrane $
 */
 
 /*! @file xmds_integrate_rk4.cc
@@ -153,12 +153,16 @@ void xmdsIntegrateRK4::writeMainIntegrateRoutine(
   fprintf(outfile, "void _segment%li(unsigned long cycle) {\n", segmentNumber);
   fprintf(outfile, "\n");
   if ((simulation()->parameters()->usempi)&!(simulation()->parameters()->stochastic)){
-    fprintf(outfile, "%s *_akfield_%s_main = (%s*)fftw_malloc(sizeof(%s)*total_local_size*_%s_main_ncomponents);\n", typeName, fieldName, typeName, typeName, fieldName);
-    fprintf(outfile, "%s *_aifield_%s_main = (%s*)fftw_malloc(sizeof(%s)*total_local_size*_%s_main_ncomponents);\n", typeName, fieldName, typeName, typeName, fieldName);
+    fprintf(outfile, "%s *_akfield_%s_main = (%s*)fftw_malloc(sizeof(%s)*total_local_size*_%s_main_ncomponents);\n",
+            typeName, fieldName, typeName, typeName, fieldName);
+    fprintf(outfile, "%s *_aifield_%s_main = (%s*)fftw_malloc(sizeof(%s)*total_local_size*_%s_main_ncomponents);\n",
+            typeName, fieldName, typeName, typeName, fieldName);
   }
   else {
-    fprintf(outfile, "%s *_akfield_%s_main = (%s*)fftw_malloc(sizeof(%s)*_%s_size*_%s_main_ncomponents);\n", typeName, fieldName, typeName, typeName, fieldName, fieldName);
-    fprintf(outfile, "%s *_aifield_%s_main = (%s*)fftw_malloc(sizeof(%s)*_%s_size*_%s_main_ncomponents);\n", typeName, fieldName, typeName, typeName, fieldName, fieldName);
+    fprintf(outfile, "%s *_akfield_%s_main = (%s*)fftw_malloc(sizeof(%s)*_%s_size*_%s_main_ncomponents);\n",
+            typeName, fieldName, typeName, typeName, fieldName, fieldName);
+    fprintf(outfile, "%s *_aifield_%s_main = (%s*)fftw_malloc(sizeof(%s)*_%s_size*_%s_main_ncomponents);\n",
+            typeName, fieldName, typeName, typeName, fieldName, fieldName);
   }
   fprintf(outfile, "\n");
   if ((simulation()->parameters()->stochastic)&&(!noNoises())) {
@@ -176,7 +180,6 @@ void xmdsIntegrateRK4::writeMainIntegrateRoutine(
 
   fprintf(outfile, "for (unsigned long _i0=0; _i0<%li; _i0++) {\n", lattice());
   fprintf(outfile, "\n");
-  writeRuntimeCheckingCode(outfile);
 
   if (simulation()->parameters()->errorCheck) {
     fprintf(outfile, " if (_half_step) {\n");
@@ -241,16 +244,25 @@ void xmdsIntegrateRK4::writeMainIntegrateRoutine(
     writeSingleStepCode(outfile, FULLSTEP);
   }
 
+  // Check if we need to halt before we try to take any samples.
+  // This will take any last sample.
+  writeHaltCheckingCode(outfile);
+
+  //! \todo This code is repeated in other integrate classes
   for (unsigned long i=0; i<simulation()->output()->nMomentGroups(); i++) {
     if (samples(i)!=0){
       fprintf(outfile, "\n");
+      fprintf(outfile, "\n// Only sample on multiples of lattice()/samples(i).\n");
+      //! \todo Why not use: if ((i0 + 1) % (lattice()/samples(i)) == 0) ?
       fprintf(outfile, " if (%li*((_i0+1)/%li)==(_i0+1))\n", lattice()/samples(i), lattice()/samples(i));
       fprintf(outfile, "   _mg%li_sample();\n", i);
     }
   }
   fprintf(outfile, " }\n");
-  if (simulation()->parameters()->runTimeLimit > 0.0)
-    fprintf(outfile, "_SEGMENT%li_END:\n", segmentNumber);
+
+  //! \todo This code is repeated in other integrate classes
+  // This label is used in the halt checking code
+  fprintf(outfile, "_SEGMENT%li_END:\n", segmentNumber);
 
   if ((simulation()->parameters()->stochastic)&&(!noNoises())) {
     fprintf(outfile, "    delete[] _noise_vector;\n");
@@ -303,7 +315,9 @@ void xmdsIntegrateRK4::writeCalculateCrossFieldRoutine(
 
   list<XMLString> myMainVectorNamesList;
 
-  for (list<XMLString>::const_iterator pXMLString = vectorNamesList()->begin(); pXMLString != vectorNamesList()->end(); pXMLString++) {
+  for (list<XMLString>::const_iterator pXMLString = vectorNamesList()->begin();
+       pXMLString != vectorNamesList()->end();
+       pXMLString++) {
     list<XMLString>::const_iterator pXMLString2 = crossVectorNamesList()->begin();
     while ((pXMLString2 != crossVectorNamesList()->end()) && (*pXMLString2 != *pXMLString)) {
       pXMLString2++;
@@ -316,7 +330,9 @@ void xmdsIntegrateRK4::writeCalculateCrossFieldRoutine(
   const char* typeName;
   list<const xmdsVector*> mainVectorList;
 
-  for (list<XMLString>::const_iterator pXMLString = myMainVectorNamesList.begin(); pXMLString != myMainVectorNamesList.end(); pXMLString++) {
+  for (list<XMLString>::const_iterator pXMLString = myMainVectorNamesList.begin();
+       pXMLString != myMainVectorNamesList.end();
+       pXMLString++) {
 
     const xmdsVector* mainVector;
 
@@ -340,7 +356,9 @@ void xmdsIntegrateRK4::writeCalculateCrossFieldRoutine(
 
   list<const xmdsVector*> crossVectorList;
 
-  for (list<XMLString>::const_iterator pXMLString = crossVectorNamesList()->begin(); pXMLString != crossVectorNamesList()->end(); pXMLString++) {
+  for (list<XMLString>::const_iterator pXMLString = crossVectorNamesList()->begin();
+       pXMLString != crossVectorNamesList()->end();
+       pXMLString++) {
 
     const xmdsVector* crossVector;
 
@@ -358,11 +376,14 @@ void xmdsIntegrateRK4::writeCalculateCrossFieldRoutine(
     }
 
     fprintf(outfile, "%s *_%s_%s_K = (%s*)fftw_malloc(sizeof(%s)*_%s_cross_size*_%s_%s_ncomponents);\n",
-            typeName, fieldName, crossVector->name()->c_str(), typeName, typeName, fieldName, fieldName, crossVector->name()->c_str());
+            typeName, fieldName, crossVector->name()->c_str(), typeName, typeName, fieldName, fieldName,
+            crossVector->name()->c_str());
     fprintf(outfile, "%s *_%s_%s_I = (%s*)fftw_malloc(sizeof(%s)*_%s_cross_size*_%s_%s_ncomponents);\n",
-            typeName, fieldName, crossVector->name()->c_str(), typeName, typeName, fieldName, fieldName, crossVector->name()->c_str());
+            typeName, fieldName, crossVector->name()->c_str(), typeName, typeName, fieldName, fieldName,
+            crossVector->name()->c_str());
     fprintf(outfile, "%s *_%s_%s_d = (%s*)fftw_malloc(sizeof(%s)*_%s_cross_size*_%s_%s_ncomponents);\n",
-            typeName, fieldName, crossVector->name()->c_str(), typeName, typeName, fieldName, fieldName, crossVector->name()->c_str());
+            typeName, fieldName, crossVector->name()->c_str(), typeName, typeName, fieldName, fieldName,
+            crossVector->name()->c_str());
     fprintf(outfile, "\n");
 
     for (unsigned long i=0; i<crossVector->nComponents(); i++) {
@@ -377,7 +398,9 @@ void xmdsIntegrateRK4::writeCalculateCrossFieldRoutine(
 
   list<XMLString> myTotalVectorsList = myMainVectorNamesList;
 
-  for (list<XMLString>::const_iterator pXMLString = crossVectorNamesList()->begin(); pXMLString != crossVectorNamesList()->end(); pXMLString++) {
+  for (list<XMLString>::const_iterator pXMLString = crossVectorNamesList()->begin();
+       pXMLString != crossVectorNamesList()->end();
+       pXMLString++) {
     myTotalVectorsList.push_back(*pXMLString);
   }
 
@@ -562,15 +585,32 @@ void xmdsIntegrateRK4::writeCalculateCrossFieldRoutine(
 
   fprintf(outfile, "%s// create midpoint main vectors for steps 2 and 3\n", indent);
   fprintf(outfile, "\n");
-  for (list<XMLString>::const_iterator pXMLString = myMainVectorNamesList.begin(); pXMLString != myMainVectorNamesList.end(); pXMLString++) {
-    fprintf(outfile, "%sfor (unsigned long _j=_%s_%s_index_pointer_begin; _j < _%s_%s_index_pointer_begin + _%s_cross_size*_%s_%s_ncomponents; _j++)\n",
+  // Only evaluate the midpoint as the average of the surrounding steps when we are at either of the edges
+  fprintf(outfile, "%1$sif (_i%2$lu == 0 || _i%2$lu == (_%3$s_lattice%2$lu-2)) {\n", indent, crossDimNumber(), fieldName);
+  for(list<XMLString>::const_iterator pXMLString = myMainVectorNamesList.begin(); pXMLString != myMainVectorNamesList.end(); pXMLString++) {
+    fprintf(outfile, "%sfor(unsigned long _j=_%s_%s_index_pointer_begin; _j < _%s_%s_index_pointer_begin + _%s_cross_size*_%s_%s_ncomponents; _j++)\n",
             indent, fieldName, pXMLString->c_str(), fieldName, pXMLString->c_str(), fieldName, fieldName, pXMLString->c_str());
     fprintf(outfile, "%s _active_%s_%s[_j] = (_active_%s_%s[_j]+_active_%s_%s[_%s_cross_size*_%s_%s_ncomponents + _j])/2;\n",
             indent, fieldName, pXMLString->c_str(), fieldName, pXMLString->c_str(), fieldName, pXMLString->c_str(),
             fieldName, fieldName, pXMLString->c_str());
     fprintf(outfile, "\n");
   }
-  fprintf(outfile, "%s// move cross dim to lattice midpoint for steps 2 and 3\n", indent);
+
+  fprintf(outfile, "%s} else {\n", indent);
+  // Evaluate the midpoint using 4 values (i.e. not linear interpolation)
+  for(list<XMLString>::const_iterator pXMLString = myMainVectorNamesList.begin(); pXMLString != myMainVectorNamesList.end(); pXMLString++) {
+    fprintf(outfile, "%sfor(unsigned long _j=_%s_%s_index_pointer_begin; _j < _%s_%s_index_pointer_begin + _%s_cross_size*_%s_%s_ncomponents; _j++)\n",
+            indent, fieldName, pXMLString->c_str(), fieldName, pXMLString->c_str(), fieldName, fieldName, pXMLString->c_str());
+    fprintf(outfile, "%s _active_%s_%s[_j] = (_active_%s_%s[_j]+_active_%s_%s[_%s_cross_size*_%s_%s_ncomponents + _j])*9.0/16.0 ",
+            indent, fieldName, pXMLString->c_str(), fieldName, pXMLString->c_str(), fieldName, pXMLString->c_str(),
+            fieldName, fieldName, pXMLString->c_str());
+          fprintf(outfile, "- (_active_%1$s_%2$s[_j - _%1$s_cross_size*_%1$s_%2$s_ncomponents] + _active_%1$s_%2$s[_j + 2*_%1$s_cross_size*_%1$s_%2$s_ncomponents])/16.0;\n", fieldName, pXMLString->c_str());
+    fprintf(outfile,"\n");
+  }
+  fprintf(outfile, "%s}\n", indent);
+  
+  
+  fprintf(outfile, "%s// move cross dim to lattice midpoint for steps 2 and 3\n",indent);
   fprintf(outfile, "\n");
   fprintf(outfile, "%s%s += _%s_dx%li/2;\n",
           indent, simulation()->field()->geometry()->dimension(crossDimNumber())->name.c_str(), fieldName, crossDimNumber());
