@@ -1,6 +1,6 @@
 
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -22,7 +22,7 @@
 */
 
 /*
-  $Id: xmds_integrate_rk9.cc 1599 2007-11-17 13:42:49Z paultcochrane $
+  $Id: xmds_integrate_rk9.cc 1885 2008-03-18 15:24:56Z paultcochrane $
 */
 
 /*! @file xmds_integrate_rk9.cc
@@ -324,7 +324,6 @@ void xmdsIntegrateRK9::writeMainIntegrateRoutine(
 
   fprintf(outfile, "for (unsigned long _i0=0; _i0<%li; _i0++) {\n", lattice());
   fprintf(outfile, "\n");
-  writeRuntimeCheckingCode(outfile);
 
   if (simulation()->parameters()->errorCheck) {
     fprintf(outfile, " if (_half_step) {\n");
@@ -389,6 +388,10 @@ void xmdsIntegrateRK9::writeMainIntegrateRoutine(
     writeSingleStepCode(outfile, FULLSTEP);
   }
 
+  // Check if we need to halt before we try to take any samples.
+  // This will take any last sample.
+  writeHaltCheckingCode(outfile);
+
   for (unsigned long i=0; i<simulation()->output()->nMomentGroups(); i++) {
     if (samples(i)!=0){
       fprintf(outfile, "\n");
@@ -398,8 +401,8 @@ void xmdsIntegrateRK9::writeMainIntegrateRoutine(
   }
   fprintf(outfile, " }\n");
 
-  if (simulation()->parameters()->runTimeLimit > 0.0)
-    fprintf(outfile, "_SEGMENT%li_END:\n", segmentNumber);
+  // This label is used in the halt checking code
+  fprintf(outfile, "_SEGMENT%li_END:\n", segmentNumber);
 
   if ((simulation()->parameters()->stochastic)&&(!noNoises())) {
     fprintf(outfile, "    delete[] _noise_vector;\n");
