@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: xmds_simulation.cc 1629 2007-12-21 18:26:49Z paultcochrane $
+  $Id: xmds_simulation.cc 1923 2008-03-27 03:15:55Z grahamdennis $
 */
 
 /*! @file xmds_simulation.cc
@@ -1299,6 +1299,9 @@ void xmdsSimulation::writeGlobals(
 
   fprintf(outfile, "\n\nlong _breakpointAutoIncrementCounter = 0;\n");
 
+  fprintf(outfile, "\n\nstring _output_filename = \"%s\";\n",
+      myOutput->getOutputFileName().c_str());
+
   xmdsElement::writeGlobals(outfile);
   fprintf(outfile, "\n");
 }
