@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: xmds_vector.cc 1640 2008-01-10 00:11:32Z joehope $
+  $Id: xmds_vector.cc 1885 2008-03-18 15:24:56Z paultcochrane $
 */
 
 /*! @file xmds_vector.cc
@@ -68,79 +68,79 @@ xmdsVector::~xmdsVector() {
 // **************************************************************************
 void xmdsVector::writeDefines(
                               FILE *const outfile) const {
-	if (debugFlag) {
-		printf("xmdsVector::writeDefines\n");
-	}
-	
-	fprintf(outfile, "// vector %s defines\n", myName.c_str());
-	if(myComponentsLengthsList.size()>0) {
-		long totalComponents = 0;
-		for ( list<long>::const_iterator pLong = myComponentsLengthsList.begin(); pLong != myComponentsLengthsList.end(); pLong++) {
-			totalComponents += *pLong;
-		}
-		fprintf(outfile, "#define _%s_%s_ncomponents %li\n", field()->name()->c_str(), myName.c_str(), totalComponents);
-	}
-	else {
-		fprintf(outfile, "#define _%s_%s_ncomponents %li\n", field()->name()->c_str(), myName.c_str(), (long)myComponentsNamesList.size());
-	}
-	
-	if(myComponentsLengthsList.size()>0) {
-		if (myComponentsLengthsList.size()!=myComponentsNamesList.size()) {
-			throw xmdsException("List of component lengths has a different size than the list of components");
-		}
-		else {
-			unsigned long totalComponents = 0;
-			list<long>::const_iterator pLong = myComponentsLengthsList.begin();
-			list<XMLString>::const_iterator pXMLString = myComponentsNamesList.begin();
-			
-			if(*pLong==1) {
-				fprintf(outfile, "#define %s _active_%s_%s[_%s_%s_index_pointer]\n",
-						pXMLString->c_str(), field()->name()->c_str(), myName.c_str(), field()->name()->c_str(), myName.c_str());
-			}
-			else if (*pLong>1) {
-				fprintf(outfile, "#define %s(j) _active_%s_%s[_%s_%s_index_pointer + j - 1]\n",
-						pXMLString->c_str(), field()->name()->c_str(), myName.c_str(), field()->name()->c_str(), myName.c_str());
+  if (debugFlag) {
+    printf("xmdsVector::writeDefines\n");
+  }
+  
+  fprintf(outfile, "// vector %s defines\n", myName.c_str());
+  if (myComponentsLengthsList.size()>0) {
+    long totalComponents = 0;
+    for (list<long>::const_iterator pLong = myComponentsLengthsList.begin(); pLong != myComponentsLengthsList.end(); pLong++) {
+      totalComponents += *pLong;
+    }
+    fprintf(outfile, "#define _%s_%s_ncomponents %li\n", field()->name()->c_str(), myName.c_str(), totalComponents);
+  }
+  else {
+    fprintf(outfile, "#define _%s_%s_ncomponents %li\n", field()->name()->c_str(), myName.c_str(), (long)myComponentsNamesList.size());
+  }
+  
+  if (myComponentsLengthsList.size()>0) {
+    if (myComponentsLengthsList.size()!=myComponentsNamesList.size()) {
+      throw xmdsException("List of component lengths has a different size than the list of components");
+    }
+    else {
+      unsigned long totalComponents = 0;
+      list<long>::const_iterator pLong = myComponentsLengthsList.begin();
+      list<XMLString>::const_iterator pXMLString = myComponentsNamesList.begin();
+      
+      if (*pLong==1) {
+        fprintf(outfile, "#define %s _active_%s_%s[_%s_%s_index_pointer]\n",
+            pXMLString->c_str(), field()->name()->c_str(), myName.c_str(), field()->name()->c_str(), myName.c_str());
+      }
+      else if (*pLong>1) {
+        fprintf(outfile, "#define %s(j) _active_%s_%s[_%s_%s_index_pointer + j - 1]\n",
+            pXMLString->c_str(), field()->name()->c_str(), myName.c_str(), field()->name()->c_str(), myName.c_str());
 //  Moved this next line into the integrate blocks themselves
-//				fprintf(outfile, "#define d%s_d%s(j) d%s_d%s[j-1]\n",
-//						pXMLString->c_str(),field()->simulation()->parameters()->propDimName.c_str(),pXMLString->c_str(),field()->simulation()->parameters()->propDimName.c_str());
-			}
-			else 
-				throw xmdsException("Component lengths has a nonpositive integer.");
-			
-			totalComponents+=*pLong;
-			pLong++;
-			pXMLString++;
-			
-			while(pXMLString != myComponentsNamesList.end()) {
-				if(*pLong==1) {
-					fprintf(outfile, "#define %s _active_%s_%s[_%s_%s_index_pointer + %li]\n",
-							pXMLString->c_str(), field()->name()->c_str(), myName.c_str(), field()->name()->c_str(), myName.c_str(),totalComponents);
-				}
-				else if (*pLong>1) {
-					fprintf(outfile, "#define %s(j) _active_%s_%s[_%s_%s_index_pointer + j + %li]\n",
-							pXMLString->c_str(), field()->name()->c_str(), myName.c_str(), field()->name()->c_str(), myName.c_str(),totalComponents-1);
+//        fprintf(outfile, "#define d%s_d%s(j) d%s_d%s[j-1]\n",
+//            pXMLString->c_str(),field()->simulation()->parameters()->propDimName.c_str(),pXMLString->c_str(),field()->simulation()->parameters()->propDimName.c_str());
+      }
+      else
+        throw xmdsException("Component lengths has a nonpositive integer.");
+      
+      totalComponents+=*pLong;
+      pLong++;
+      pXMLString++;
+      
+      while (pXMLString != myComponentsNamesList.end()) {
+        if (*pLong==1) {
+          fprintf(outfile, "#define %s _active_%s_%s[_%s_%s_index_pointer + %li]\n",
+              pXMLString->c_str(), field()->name()->c_str(), myName.c_str(), field()->name()->c_str(), myName.c_str(),totalComponents);
+        }
+        else if (*pLong>1) {
+          fprintf(outfile, "#define %s(j) _active_%s_%s[_%s_%s_index_pointer + j + %li]\n",
+              pXMLString->c_str(), field()->name()->c_str(), myName.c_str(), field()->name()->c_str(), myName.c_str(),totalComponents-1);
 //  Moved this next line into the integrate blocks themselves
-//					fprintf(outfile, "#define d%s_d%s(j) d%s_d%s[j-1]\n",
-//							pXMLString->c_str(),field()->simulation()->parameters()->propDimName.c_str(),pXMLString->c_str(),field()->simulation()->parameters()->propDimName.c_str());
-				}
-				else 
-					throw xmdsException("Component lengths has a nonpositive integer.");
-			    totalComponents+=*pLong;
-				pLong++;
-				pXMLString++;
-			}
-		}
-	}
-	else {
-		unsigned long i=0;
-		for (list<XMLString>::const_iterator pXMLString = myComponentsNamesList.begin(); pXMLString != myComponentsNamesList.end(); pXMLString++) {
-			fprintf(outfile, "#define %s _active_%s_%s[_%s_%s_index_pointer + %li]\n",
-					pXMLString->c_str(), field()->name()->c_str(), myName.c_str(), field()->name()->c_str(), myName.c_str(), i);
-			i++;
-		}
-	}
-	fprintf(outfile, "\n");
-							  }
+//          fprintf(outfile, "#define d%s_d%s(j) d%s_d%s[j-1]\n",
+//              pXMLString->c_str(),field()->simulation()->parameters()->propDimName.c_str(),pXMLString->c_str(),field()->simulation()->parameters()->propDimName.c_str());
+        }
+        else
+          throw xmdsException("Component lengths has a nonpositive integer.");
+          totalComponents+=*pLong;
+        pLong++;
+        pXMLString++;
+      }
+    }
+  }
+  else {
+    unsigned long i=0;
+    for (list<XMLString>::const_iterator pXMLString = myComponentsNamesList.begin(); pXMLString != myComponentsNamesList.end(); pXMLString++) {
+      fprintf(outfile, "#define %s _active_%s_%s[_%s_%s_index_pointer + %li]\n",
+          pXMLString->c_str(), field()->name()->c_str(), myName.c_str(), field()->name()->c_str(), myName.c_str(), i);
+      i++;
+    }
+  }
+  fprintf(outfile, "\n");
+                }
 
 // **************************************************************************
 void xmdsVector::writeGlobals(
