@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: xmds_vector_element.cc 1637 2007-12-31 04:00:26Z joehope $
+  $Id: xmds_vector_element.cc 1885 2008-03-18 15:24:56Z paultcochrane $
 */
 
 /*! @file xmds_vector_element.cc
@@ -76,248 +76,248 @@ xmdsVectorElement::~xmdsVectorElement() {
 // **************************************************************************
 void xmdsVectorElement::processElement(
                                        const Element *const yourElement) {
-	if (debugFlag) {
-		printf("xmdsVectorElement::processElement\n");
-	}
-	
-	list<XMLString> anXMLStringList;
-	list<long> aLongList;
-	XMLString anXMLString;
-	
-	if (verbose()) {
-		printf("Processing vector element ...\n");
-	}
-	
-	// ************************************
-	// find name
-	
-	getAssignmentStrings(yourElement, "name", 1, 1, anXMLStringList);
-	
-	const xmdsVector* possibleTwin;
-	
-	if (field()->getVector(*anXMLStringList.begin(), possibleTwin)) {
-		sprintf(errorMessage(), "a vector of name '%s' already exists in this field", anXMLStringList.begin()->c_str());
-		throw xmdsException(yourElement, errorMessage());
-	}
-	
-	setName(*anXMLStringList.begin());
-	if (verbose()) {
-		printf("vector name is '%s'\n", name()->c_str());
-	}
-	
-	// ************************************
-	// find type
-	
-	getAssignmentStrings(yourElement, "type", 0, 1, anXMLStringList);
-	
-	if (anXMLStringList.size()==1) {
-		
-		if (*anXMLStringList.begin()=="complex") {
-			setVectorType(COMPLEX);
-			if (verbose()) {
-				printf("vector type is 'complex'\n");
-			}
-		}
-		else if (*anXMLStringList.begin()=="double") {
-			setVectorType(DOUBLE);
-			if (verbose()) {
-				printf("vector type is 'double'\n");
-			}
-		}
-		else {
-		}
-	}
-	else {
-		setVectorType(COMPLEX);
-		printf("vector type defaulting to 'complex'\n");
-	}
-	
-	// ************************************
-	// find components
-	
-	getAssignmentVectorStrings(yourElement, "components", 1, 0, anXMLStringList, aLongList);
-	
-	if (anXMLStringList.size()==0) {
-		throw xmdsException(yourElement, "No vector components specified!");
-	}
-	
-	setComponents(anXMLStringList);
-	setLengths(aLongList);
-	
-	if (verbose()) {
-		for (unsigned long i=0; i<nComponents(); i++) {
-			printf("adding vector component '%s'\n", componentName(i)->c_str());
-		}
-	}
-	
-	// ************************************
-	// find 'filename'
-	
-	getAssignmentStrings(yourElement, "filename", NOT_REQD, 1, anXMLStringList);
-	
-	if (anXMLStringList.size()==1) {
-		// we have a filename assignent
-		
-		getAttributeStrings(yourElement, "filename", "format", NOT_REQD, anXMLString);
-		myInputFileFormat = ASCII;  // the default value
-		
-		setInitialSpace(0);
-		
-		if (anXMLString != EMPTY_STRING) {
-			// a format attribute has been set
-			if (anXMLString == "binary") {
-				myInputFileFormat = BINARY;
-			}
-			else if (anXMLString == "bin") {
-				myInputFileFormat = BINARY;
-			}
-			else if (anXMLString == "ascii") {
-				myInputFileFormat = ASCII;
-			}
-			else if (anXMLString == "text") {
-				myInputFileFormat = ASCII;
-			}
-			else if (anXMLString == "txt") {
-				myInputFileFormat = ASCII;
-			}
-			else if (anXMLString == "xsil") {
-				myInputFileFormat = XSIL;
-				
-				// find the moment group that we are initialising from
-				XMLString momentGroupName;
-				getAttributeStrings(yourElement, "filename", "moment_group", NOT_REQD, momentGroupName);
-				if (momentGroupName == EMPTY_STRING)
-					myInitialisationMomentGroupName = "NULL";
-				else
-					myInitialisationMomentGroupName = string("moment_group_") + momentGroupName.c_str();
-				
-				
-				// find the geometry matching mode
-				XMLString geometryMatchMode;
-				getAttributeStrings(yourElement, "filename", "geometry_matching_mode", NOT_REQD, geometryMatchMode);
-				if (geometryMatchMode != EMPTY_STRING) {
-					if (geometryMatchMode == "strict")
-						isGeometryMatchingModeStrict = true;
-					else if (geometryMatchMode == "loose")
-						isGeometryMatchingModeStrict = false;
-					else
-						throw xmdsException(yourElement, "The geometry matching mode must be either 'strict' or 'loose'");
-				}
-				else
-					isGeometryMatchingModeStrict = true;
-				
-				if (field()->geometry()->nDims()>0) {
-					
-					// ************************************
-					// find space
-					
-					list<bool> aSpaceList;
-					
-					getAssignmentBools(yourElement, "fourier_space", 0, field()->geometry()->nDims(), aSpaceList);
-					
-					if (aSpaceList.size() == 0) {
-						printf("Initialisation space for vector '%s' defaulting to x-space.\n", name()->c_str());
-					}
-					else {
-						list<bool>::const_iterator pBool = aSpaceList.begin();
-						for (unsigned long i=0; i<field()->geometry()->nDims(); i++) {
-							if (verbose()) {
-								if (*pBool) {
-									printf("initialisation will be performed with dimension #%li in fourier space\n", i+1);
-								}
-								else {
-									printf("initialisation will be performed with dimension #%li in normal space\n", i+1);
-								}
-							}
-							pBool++;
-						}
-						setInitialSpace(spaceList2ULong(aSpaceList));
-					}
-				}
-				// ************************************
-				// find vectors
-				
-				getAssignmentStrings(yourElement, "vectors", 0, 0, myVectorNamesList);
-				
-				field()->processVectors(myVectorNamesList, initialSpace());
-				
-				// ************************************
-				// find code
-				
-				myCode=*yourElement->textContent(0);
-				
-			}
-			else {
-				throw xmdsException(yourElement,
-									"Warning: Unknown file format attribute value in 'filename' tag\nI expected either 'binary', 'ascii' or 'xsil'.");
-			}
-		}
-		
-		myFileName=*anXMLStringList.begin();
-		if (verbose()) {
-			printf("vector initialisation from file '%s'\n", myFileName.c_str());
-		}
-		
-	}
-	else {
-		// initialisation from code
-		if (verbose()) {
-			printf("initialisation from user code\n");
-		}
-		
-		setInitialSpace(0);
-		
-		if (field()->geometry()->nDims()>0) {
-			
-			// ************************************
-			// find space
-			
-			list<bool> aSpaceList;
-			
-			getAssignmentBools(yourElement, "fourier_space", 0, field()->geometry()->nDims(), aSpaceList);
-			
-			if (aSpaceList.size() == 0) {
-				printf("Initialisation space for vector '%s' defaulting to x-space.\n", name()->c_str());
-			}
-			else {
-				list<bool>::const_iterator pBool = aSpaceList.begin();
-				for (unsigned long i=0; i<field()->geometry()->nDims(); i++) {
-					if (verbose()) {
-						if (*pBool) {
-							printf("initialisation will be performed with dimension #%li in fourier space\n", i+1);
-						}
-						else {
-							printf("initialisation will be performed with dimension #%li in normal space\n", i+1);
-						}
-					}
-					pBool++;
-				}
-				setInitialSpace(spaceList2ULong(aSpaceList));
-			}
-		}
-		
-		// ************************************
-		// find vectors
-		
-		getAssignmentStrings(yourElement, "vectors", 0, 0, myVectorNamesList);
-		
-		field()->processVectors(myVectorNamesList, initialSpace());
-		
-		// ************************************
-		// find code
-		
-		myCode=*yourElement->textContent(0);
-		
-		// check for non-white space charaters in code:
-		
-		if (myCode.isAllWhiteSpace()) {
-			throw xmdsException(yourElement, "No initialisation code defined!");
-		}
-		
-		if (verbose()) {
-			printf("initialisation code loaded\n");
-		}
-	}
+  if (debugFlag) {
+    printf("xmdsVectorElement::processElement\n");
+  }
+  
+  list<XMLString> anXMLStringList;
+  list<long> aLongList;
+  XMLString anXMLString;
+  
+  if (verbose()) {
+    printf("Processing vector element ...\n");
+  }
+  
+  // ************************************
+  // find name
+  
+  getAssignmentStrings(yourElement, "name", 1, 1, anXMLStringList);
+  
+  const xmdsVector* possibleTwin;
+  
+  if (field()->getVector(*anXMLStringList.begin(), possibleTwin)) {
+    sprintf(errorMessage(), "a vector of name '%s' already exists in this field", anXMLStringList.begin()->c_str());
+    throw xmdsException(yourElement, errorMessage());
+  }
+  
+  setName(*anXMLStringList.begin());
+  if (verbose()) {
+    printf("vector name is '%s'\n", name()->c_str());
+  }
+  
+  // ************************************
+  // find type
+  
+  getAssignmentStrings(yourElement, "type", 0, 1, anXMLStringList);
+  
+  if (anXMLStringList.size()==1) {
+    
+    if (*anXMLStringList.begin()=="complex") {
+      setVectorType(COMPLEX);
+      if (verbose()) {
+        printf("vector type is 'complex'\n");
+      }
+    }
+    else if (*anXMLStringList.begin()=="double") {
+      setVectorType(DOUBLE);
+      if (verbose()) {
+        printf("vector type is 'double'\n");
+      }
+    }
+    else {
+    }
+  }
+  else {
+    setVectorType(COMPLEX);
+    printf("vector type defaulting to 'complex'\n");
+  }
+  
+  // ************************************
+  // find components
+  
+  getAssignmentVectorStrings(yourElement, "components", 1, 0, anXMLStringList, aLongList);
+  
+  if (anXMLStringList.size()==0) {
+    throw xmdsException(yourElement, "No vector components specified!");
+  }
+  
+  setComponents(anXMLStringList);
+  setLengths(aLongList);
+  
+  if (verbose()) {
+    for (unsigned long i=0; i<nComponents(); i++) {
+      printf("adding vector component '%s'\n", componentName(i)->c_str());
+    }
+  }
+  
+  // ************************************
+  // find 'filename'
+  
+  getAssignmentStrings(yourElement, "filename", NOT_REQD, 1, anXMLStringList);
+  
+  if (anXMLStringList.size()==1) {
+    // we have a filename assignent
+    
+    getAttributeStrings(yourElement, "filename", "format", NOT_REQD, anXMLString);
+    myInputFileFormat = ASCII;  // the default value
+    
+    setInitialSpace(0);
+    
+    if (anXMLString != EMPTY_STRING) {
+      // a format attribute has been set
+      if (anXMLString == "binary") {
+        myInputFileFormat = BINARY;
+      }
+      else if (anXMLString == "bin") {
+        myInputFileFormat = BINARY;
+      }
+      else if (anXMLString == "ascii") {
+        myInputFileFormat = ASCII;
+      }
+      else if (anXMLString == "text") {
+        myInputFileFormat = ASCII;
+      }
+      else if (anXMLString == "txt") {
+        myInputFileFormat = ASCII;
+      }
+      else if (anXMLString == "xsil") {
+        myInputFileFormat = XSIL;
+        
+        // find the moment group that we are initialising from
+        XMLString momentGroupName;
+        getAttributeStrings(yourElement, "filename", "moment_group", NOT_REQD, momentGroupName);
+        if (momentGroupName == EMPTY_STRING)
+          myInitialisationMomentGroupName = "NULL";
+        else
+          myInitialisationMomentGroupName = string("moment_group_") + momentGroupName.c_str();
+        
+        
+        // find the geometry matching mode
+        XMLString geometryMatchMode;
+        getAttributeStrings(yourElement, "filename", "geometry_matching_mode", NOT_REQD, geometryMatchMode);
+        if (geometryMatchMode != EMPTY_STRING) {
+          if (geometryMatchMode == "strict")
+            isGeometryMatchingModeStrict = true;
+          else if (geometryMatchMode == "loose")
+            isGeometryMatchingModeStrict = false;
+          else
+            throw xmdsException(yourElement, "The geometry matching mode must be either 'strict' or 'loose'");
+        }
+        else
+          isGeometryMatchingModeStrict = true;
+        
+        if (field()->geometry()->nDims()>0) {
+          
+          // ************************************
+          // find space
+          
+          list<bool> aSpaceList;
+          
+          getAssignmentBools(yourElement, "fourier_space", 0, field()->geometry()->nDims(), aSpaceList);
+          
+          if (aSpaceList.size() == 0) {
+            printf("Initialisation space for vector '%s' defaulting to x-space.\n", name()->c_str());
+          }
+          else {
+            list<bool>::const_iterator pBool = aSpaceList.begin();
+            for (unsigned long i=0; i<field()->geometry()->nDims(); i++) {
+              if (verbose()) {
+                if (*pBool) {
+                  printf("initialisation will be performed with dimension #%li in fourier space\n", i+1);
+                }
+                else {
+                  printf("initialisation will be performed with dimension #%li in normal space\n", i+1);
+                }
+              }
+              pBool++;
+            }
+            setInitialSpace(spaceList2ULong(aSpaceList));
+          }
+        }
+        // ************************************
+        // find vectors
+        
+        getAssignmentStrings(yourElement, "vectors", 0, 0, myVectorNamesList);
+        
+        field()->processVectors(myVectorNamesList, initialSpace());
+        
+        // ************************************
+        // find code
+        
+        myCode=*yourElement->textContent(0);
+        
+      }
+      else {
+        throw xmdsException(yourElement,
+                  "Warning: Unknown file format attribute value in 'filename' tag\nI expected either 'binary', 'ascii' or 'xsil'.");
+      }
+    }
+    
+    myFileName=*anXMLStringList.begin();
+    if (verbose()) {
+      printf("vector initialisation from file '%s'\n", myFileName.c_str());
+    }
+    
+  }
+  else {
+    // initialisation from code
+    if (verbose()) {
+      printf("initialisation from user code\n");
+    }
+    
+    setInitialSpace(0);
+    
+    if (field()->geometry()->nDims()>0) {
+      
+      // ************************************
+      // find space
+      
+      list<bool> aSpaceList;
+      
+      getAssignmentBools(yourElement, "fourier_space", 0, field()->geometry()->nDims(), aSpaceList);
+      
+      if (aSpaceList.size() == 0) {
+        printf("Initialisation space for vector '%s' defaulting to x-space.\n", name()->c_str());
+      }
+      else {
+        list<bool>::const_iterator pBool = aSpaceList.begin();
+        for (unsigned long i=0; i<field()->geometry()->nDims(); i++) {
+          if (verbose()) {
+            if (*pBool) {
+              printf("initialisation will be performed with dimension #%li in fourier space\n", i+1);
+            }
+            else {
+              printf("initialisation will be performed with dimension #%li in normal space\n", i+1);
+            }
+          }
+          pBool++;
+        }
+        setInitialSpace(spaceList2ULong(aSpaceList));
+      }
+    }
+    
+    // ************************************
+    // find vectors
+    
+    getAssignmentStrings(yourElement, "vectors", 0, 0, myVectorNamesList);
+    
+    field()->processVectors(myVectorNamesList, initialSpace());
+    
+    // ************************************
+    // find code
+    
+    myCode=*yourElement->textContent(0);
+    
+    // check for non-white space charaters in code:
+    
+    if (myCode.isAllWhiteSpace()) {
+      throw xmdsException(yourElement, "No initialisation code defined!");
+    }
+    
+    if (verbose()) {
+      printf("initialisation code loaded\n");
+    }
+  }
 }
 
 // **************************************************************************
@@ -624,10 +624,10 @@ void xmdsVectorElement::writeInitialiseRoutine(FILE *const outfile) const
               "\t for (int __i=0; __i<_%s_ndims; __i++) {\n" // loop over the dimension elements in the binary file
               "\t\t uint64_t sizeValue;\n"
               "\t\t switch(unsignedLongSize) {\n", fieldName, fieldName); // deal with the different possible sizes for the unsigned long size
-      char *string1[] = {"0", "4", "8"};
-      char *string2[] = {"ulong", "uint32", "uint64"};
-      char *string3[] = {"unsigned long", "uint32_t", "uint64_t"};
-      char *string4[] = {"XMDSSwapInt32", "XMDSSwapInt32", "XMDSSwapInt64"};
+      const char *string1[] = {"0", "4", "8"};
+      const char *string2[] = {"ulong", "uint32", "uint64"};
+      const char *string3[] = {"unsigned long", "uint32_t", "uint64_t"};
+      const char *string4[] = {"XMDSSwapInt32", "XMDSSwapInt32", "XMDSSwapInt64"};
       for (int i=0; i<3; i++) {
         fprintf(outfile, "\t\t\t case %s:\n"
                 "\t\t\t\t fread(&size.%s, sizeof(%s), 1, inputFile);\n"
