@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2007
+  Copyright (C) 2000-2008
 
   Code contributed by Greg Collecutt, Joseph Hope, Andrew Reid and Paul Cochrane
 
@@ -21,7 +21,7 @@
 */
 
 /*
-  $Id: xml_basics.cc 1624 2007-12-16 04:00:45Z joehope $
+  $Id: xml_basics.cc 1885 2008-03-18 15:24:56Z paultcochrane $
 */
 
 /*! @file xml_basics.h
@@ -878,33 +878,33 @@ void XMLString::goLatinAlphaNumeric() {
 
 // **********************************************************************
 void XMLString::goLatinAlphaNumericNoUnderScore() {
-	// A function that converts the XML string to alpha numeric characters, and
-	// also removes any underscores, since in some cases even the underscore
-	// character is unacceptable in the string.
-	
-	if (_length==0) {
-		return;
-	}
-	
-	if (_c_str_valid) {
-		delete _c_str;
-	}
-	_c_str_valid=0;
-	
-	if (!(XMLChar::isLatinLetter(_data[0]))) {
-		_data[0]='x';
-	}
-	
-	long nextValid = 1;
-	for (unsigned long i=1; i<_length; i++) {
-		if (XMLChar::isLatinLetter(_data[i])|XMLChar::isLatinDigit(_data[i])) {
-			_data[nextValid]=_data[i];
-			nextValid++;
-		}
-	}
-	
-	_length=nextValid;
-	}
+  // A function that converts the XML string to alpha numeric characters, and
+  // also removes any underscores, since in some cases even the underscore
+  // character is unacceptable in the string.
+  
+  if (_length==0) {
+    return;
+  }
+  
+  if (_c_str_valid) {
+    delete _c_str;
+  }
+  _c_str_valid=0;
+  
+  if (!(XMLChar::isLatinLetter(_data[0]))) {
+    _data[0]='x';
+  }
+  
+  long nextValid = 1;
+  for (unsigned long i=1; i<_length; i++) {
+    if (XMLChar::isLatinLetter(_data[i])|XMLChar::isLatinDigit(_data[i])) {
+      _data[nextValid]=_data[i];
+      nextValid++;
+    }
+  }
+  
+  _length=nextValid;
+  }
 
 /*
  * Local variables:
